#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .cathode_cc_zone import cathode_cc_zone as cathode_cc_zone_cls
from .cathode_fc_zone import cathode_fc_zone as cathode_fc_zone_cls
from .cathode_pl_zone import cathode_pl_zone as cathode_pl_zone_cls
from .cathode_pl_cp_function import cathode_pl_cp_function as cathode_pl_cp_function_cls
from .cathode_pl_angle import cathode_pl_angle as cathode_pl_angle_cls
from .cathode_pl_a import cathode_pl_a as cathode_pl_a_cls
from .cathode_pl_b import cathode_pl_b as cathode_pl_b_cls
from .cathode_pl_c import cathode_pl_c as cathode_pl_c_cls
from .cathode_cl_zone import cathode_cl_zone as cathode_cl_zone_cls
from .cathode_cl_svratio import cathode_cl_svratio as cathode_cl_svratio_cls
from .cathode_cl_thickness import cathode_cl_thickness as cathode_cl_thickness_cls
from .cathode_cl_cp_function import cathode_cl_cp_function as cathode_cl_cp_function_cls
from .cathode_cl_angle import cathode_cl_angle as cathode_cl_angle_cls
from .cathode_cl_a import cathode_cl_a as cathode_cl_a_cls
from .cathode_cl_b import cathode_cl_b as cathode_cl_b_cls
from .cathode_cl_c import cathode_cl_c as cathode_cl_c_cls
class cathode(Group):
    """
    'cathode' child.
    """

    fluent_name = "cathode"

    child_names = \
        ['cathode_cc_zone', 'cathode_fc_zone', 'cathode_pl_zone',
         'cathode_pl_cp_function', 'cathode_pl_angle', 'cathode_pl_a',
         'cathode_pl_b', 'cathode_pl_c', 'cathode_cl_zone',
         'cathode_cl_svratio', 'cathode_cl_thickness',
         'cathode_cl_cp_function', 'cathode_cl_angle', 'cathode_cl_a',
         'cathode_cl_b', 'cathode_cl_c']

    cathode_cc_zone: cathode_cc_zone_cls = cathode_cc_zone_cls
    """
    cathode_cc_zone child of cathode.
    """
    cathode_fc_zone: cathode_fc_zone_cls = cathode_fc_zone_cls
    """
    cathode_fc_zone child of cathode.
    """
    cathode_pl_zone: cathode_pl_zone_cls = cathode_pl_zone_cls
    """
    cathode_pl_zone child of cathode.
    """
    cathode_pl_cp_function: cathode_pl_cp_function_cls = cathode_pl_cp_function_cls
    """
    cathode_pl_cp_function child of cathode.
    """
    cathode_pl_angle: cathode_pl_angle_cls = cathode_pl_angle_cls
    """
    cathode_pl_angle child of cathode.
    """
    cathode_pl_a: cathode_pl_a_cls = cathode_pl_a_cls
    """
    cathode_pl_a child of cathode.
    """
    cathode_pl_b: cathode_pl_b_cls = cathode_pl_b_cls
    """
    cathode_pl_b child of cathode.
    """
    cathode_pl_c: cathode_pl_c_cls = cathode_pl_c_cls
    """
    cathode_pl_c child of cathode.
    """
    cathode_cl_zone: cathode_cl_zone_cls = cathode_cl_zone_cls
    """
    cathode_cl_zone child of cathode.
    """
    cathode_cl_svratio: cathode_cl_svratio_cls = cathode_cl_svratio_cls
    """
    cathode_cl_svratio child of cathode.
    """
    cathode_cl_thickness: cathode_cl_thickness_cls = cathode_cl_thickness_cls
    """
    cathode_cl_thickness child of cathode.
    """
    cathode_cl_cp_function: cathode_cl_cp_function_cls = cathode_cl_cp_function_cls
    """
    cathode_cl_cp_function child of cathode.
    """
    cathode_cl_angle: cathode_cl_angle_cls = cathode_cl_angle_cls
    """
    cathode_cl_angle child of cathode.
    """
    cathode_cl_a: cathode_cl_a_cls = cathode_cl_a_cls
    """
    cathode_cl_a child of cathode.
    """
    cathode_cl_b: cathode_cl_b_cls = cathode_cl_b_cls
    """
    cathode_cl_b child of cathode.
    """
    cathode_cl_c: cathode_cl_c_cls = cathode_cl_c_cls
    """
    cathode_cl_c child of cathode.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

"""A package providing Fluent's Settings Objects in Python."""
from ansys.fluent.core.solver.flobject import *

SHASH = "0151694c92fe1b6bfd5c2130d091ab5931e336e033dfde33304ad75d89fb41ab"
from .root import root


#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class raytracing_options:
    fluent_name = ...
    child_names = ...
    background = ...
    rendering = ...
    command_names = ...

    def display_live_preview(self, ):
        """
        Display the raytracing rendering for the active window.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class target_cells_per_volume_cluster(Integer):
    """
    'target_cells_per_volume_cluster' child.
    """

    fluent_name = "target-cells-per-volume-cluster"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class gaussian_factor(Real):
    """
    Set a factor for the gaussian kernel for node-based averaging.~%Large values give small size, small values give large size of kernel.
    """

    fluent_name = "gaussian-factor"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .domain import domain as domain_cls
from .cell_zones_1 import cell_zones as cell_zones_cls
from .register_id import register_id as register_id_cls
from .variable import variable as variable_cls
from .patch_velocity import patch_velocity as patch_velocity_cls
from .use_custom_field_function import use_custom_field_function as use_custom_field_function_cls
from .custom_field_function_name import custom_field_function_name as custom_field_function_name_cls
from .value import value as value_cls
class calculate_patch(Command):
    """
    Patch a value for a flow variable in the domain.
    
    Parameters
    ----------
        domain : str
            'domain' child.
        cell_zones : typing.List[str]
            'cell_zones' child.
        register_id : typing.List[str]
            'register_id' child.
        variable : str
            'variable' child.
        patch_velocity : bool
            'patch_velocity' child.
        use_custom_field_function : bool
            'use_custom_field_function' child.
        custom_field_function_name : str
            'custom_field_function_name' child.
        value : real
            'value' child.
    
    """

    fluent_name = "calculate-patch"

    argument_names = \
        ['domain', 'cell_zones', 'register_id', 'variable', 'patch_velocity',
         'use_custom_field_function', 'custom_field_function_name', 'value']

    domain: domain_cls = domain_cls
    """
    domain argument of calculate_patch.
    """
    cell_zones: cell_zones_cls = cell_zones_cls
    """
    cell_zones argument of calculate_patch.
    """
    register_id: register_id_cls = register_id_cls
    """
    register_id argument of calculate_patch.
    """
    variable: variable_cls = variable_cls
    """
    variable argument of calculate_patch.
    """
    patch_velocity: patch_velocity_cls = patch_velocity_cls
    """
    patch_velocity argument of calculate_patch.
    """
    use_custom_field_function: use_custom_field_function_cls = use_custom_field_function_cls
    """
    use_custom_field_function argument of calculate_patch.
    """
    custom_field_function_name: custom_field_function_name_cls = custom_field_function_name_cls
    """
    custom_field_function_name argument of calculate_patch.
    """
    value: value_cls = value_cls
    """
    value argument of calculate_patch.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .cycle_type import cycle_type as cycle_type_cls
from .termination_criteria import termination_criteria as termination_criteria_cls
from .residual_reduction_tolerance import residual_reduction_tolerance as residual_reduction_tolerance_cls
from .method_8 import method as method_cls
from .stabilization import stabilization as stabilization_cls
class mg_controls_child(Group):
    """
    'child_object_type' of mg_controls.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['cycle_type', 'termination_criteria', 'residual_reduction_tolerance',
         'method', 'stabilization']

    cycle_type: cycle_type_cls = cycle_type_cls
    """
    cycle_type child of mg_controls_child.
    """
    termination_criteria: termination_criteria_cls = termination_criteria_cls
    """
    termination_criteria child of mg_controls_child.
    """
    residual_reduction_tolerance: residual_reduction_tolerance_cls = residual_reduction_tolerance_cls
    """
    residual_reduction_tolerance child of mg_controls_child.
    """
    method: method_cls = method_cls
    """
    method child of mg_controls_child.
    """
    stabilization: stabilization_cls = stabilization_cls
    """
    stabilization child of mg_controls_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .coupling import coupling as coupling_cls
from .helper_session_setup import helper_session_setup as helper_session_setup_cls
from .helper_session import helper_session as helper_session_cls
class set(Group):
    """
    Enter the set menu for loosely coupled conjugate heat transfer.
    """

    fluent_name = "set"

    child_names = \
        ['coupling', 'helper_session_setup', 'helper_session']

    coupling: coupling_cls = coupling_cls
    """
    coupling child of set.
    """
    helper_session_setup: helper_session_setup_cls = helper_session_setup_cls
    """
    helper_session_setup child of set.
    """
    helper_session: helper_session_cls = helper_session_cls
    """
    helper_session child of set.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name import name as name_cls
from .chemical_formula import chemical_formula as chemical_formula_cls
from .density_4 import density as density_cls
from .thermal_conductivity_3 import thermal_conductivity as thermal_conductivity_cls
from .latent_heat_1 import latent_heat as latent_heat_cls
from .volatile_fraction import volatile_fraction as volatile_fraction_cls
from .combustible_fraction import combustible_fraction as combustible_fraction_cls
from .swelling_coefficient import swelling_coefficient as swelling_coefficient_cls
from .burn_stoichiometry import burn_stoichiometry as burn_stoichiometry_cls
from .specific_heat_3 import specific_heat as specific_heat_cls
from .binary_diffusivity_2 import binary_diffusivity as binary_diffusivity_cls
from .diffusivity_reference_pressure import diffusivity_reference_pressure as diffusivity_reference_pressure_cls
from .vaporization_temperature import vaporization_temperature as vaporization_temperature_cls
from .thermophoretic_co import thermophoretic_co as thermophoretic_co_cls
from .burn_hreact import burn_hreact as burn_hreact_cls
from .burn_hreact_fraction import burn_hreact_fraction as burn_hreact_fraction_cls
from .devolatilization_model import devolatilization_model as devolatilization_model_cls
from .combustion_model import combustion_model as combustion_model_cls
from .scattering_factor_1 import scattering_factor as scattering_factor_cls
from .emissivity_1 import emissivity as emissivity_cls
class combusting_particle_child(Group):
    """
    'child_object_type' of combusting_particle.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'chemical_formula', 'density', 'thermal_conductivity',
         'latent_heat', 'volatile_fraction', 'combustible_fraction',
         'swelling_coefficient', 'burn_stoichiometry', 'specific_heat',
         'binary_diffusivity', 'diffusivity_reference_pressure',
         'vaporization_temperature', 'thermophoretic_co', 'burn_hreact',
         'burn_hreact_fraction', 'devolatilization_model', 'combustion_model',
         'scattering_factor', 'emissivity']

    name: name_cls = name_cls
    """
    name child of combusting_particle_child.
    """
    chemical_formula: chemical_formula_cls = chemical_formula_cls
    """
    chemical_formula child of combusting_particle_child.
    """
    density: density_cls = density_cls
    """
    density child of combusting_particle_child.
    """
    thermal_conductivity: thermal_conductivity_cls = thermal_conductivity_cls
    """
    thermal_conductivity child of combusting_particle_child.
    """
    latent_heat: latent_heat_cls = latent_heat_cls
    """
    latent_heat child of combusting_particle_child.
    """
    volatile_fraction: volatile_fraction_cls = volatile_fraction_cls
    """
    volatile_fraction child of combusting_particle_child.
    """
    combustible_fraction: combustible_fraction_cls = combustible_fraction_cls
    """
    combustible_fraction child of combusting_particle_child.
    """
    swelling_coefficient: swelling_coefficient_cls = swelling_coefficient_cls
    """
    swelling_coefficient child of combusting_particle_child.
    """
    burn_stoichiometry: burn_stoichiometry_cls = burn_stoichiometry_cls
    """
    burn_stoichiometry child of combusting_particle_child.
    """
    specific_heat: specific_heat_cls = specific_heat_cls
    """
    specific_heat child of combusting_particle_child.
    """
    binary_diffusivity: binary_diffusivity_cls = binary_diffusivity_cls
    """
    binary_diffusivity child of combusting_particle_child.
    """
    diffusivity_reference_pressure: diffusivity_reference_pressure_cls = diffusivity_reference_pressure_cls
    """
    diffusivity_reference_pressure child of combusting_particle_child.
    """
    vaporization_temperature: vaporization_temperature_cls = vaporization_temperature_cls
    """
    vaporization_temperature child of combusting_particle_child.
    """
    thermophoretic_co: thermophoretic_co_cls = thermophoretic_co_cls
    """
    thermophoretic_co child of combusting_particle_child.
    """
    burn_hreact: burn_hreact_cls = burn_hreact_cls
    """
    burn_hreact child of combusting_particle_child.
    """
    burn_hreact_fraction: burn_hreact_fraction_cls = burn_hreact_fraction_cls
    """
    burn_hreact_fraction child of combusting_particle_child.
    """
    devolatilization_model: devolatilization_model_cls = devolatilization_model_cls
    """
    devolatilization_model child of combusting_particle_child.
    """
    combustion_model: combustion_model_cls = combustion_model_cls
    """
    combustion_model child of combusting_particle_child.
    """
    scattering_factor: scattering_factor_cls = scattering_factor_cls
    """
    scattering_factor child of combusting_particle_child.
    """
    emissivity: emissivity_cls = emissivity_cls
    """
    emissivity child of combusting_particle_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name_1 import name as name_cls
class delete(Command):
    """
    Delete a mesh interface.
    
    Parameters
    ----------
        name : str
            'name' child.
    
    """

    fluent_name = "delete"

    argument_names = \
        ['name']

    name: name_cls = name_cls
    """
    name argument of delete.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name_1 import name as name_cls
from .chemical_formula import chemical_formula as chemical_formula_cls
from .density_3 import density as density_cls
from .specific_heat_3 import specific_heat as specific_heat_cls
from .thermal_conductivity_3 import thermal_conductivity as thermal_conductivity_cls
from .thermophoretic_co import thermophoretic_co as thermophoretic_co_cls
from .scattering_factor import scattering_factor as scattering_factor_cls
from .emissivity import emissivity as emissivity_cls
from .viscosity_2 import viscosity as viscosity_cls
from .dpm_surften import dpm_surften as dpm_surften_cls
from .electric_conductivity_1 import electric_conductivity as electric_conductivity_cls
from .dual_electric_conductivity_1 import dual_electric_conductivity as dual_electric_conductivity_cls
from .magnetic_permeability import magnetic_permeability as magnetic_permeability_cls
from .charge_density import charge_density as charge_density_cls
class inert_particle_child(Group):
    """
    'child_object_type' of inert_particle.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'chemical_formula', 'density', 'specific_heat',
         'thermal_conductivity', 'thermophoretic_co', 'scattering_factor',
         'emissivity', 'viscosity', 'dpm_surften', 'electric_conductivity',
         'dual_electric_conductivity', 'magnetic_permeability',
         'charge_density']

    name: name_cls = name_cls
    """
    name child of inert_particle_child.
    """
    chemical_formula: chemical_formula_cls = chemical_formula_cls
    """
    chemical_formula child of inert_particle_child.
    """
    density: density_cls = density_cls
    """
    density child of inert_particle_child.
    """
    specific_heat: specific_heat_cls = specific_heat_cls
    """
    specific_heat child of inert_particle_child.
    """
    thermal_conductivity: thermal_conductivity_cls = thermal_conductivity_cls
    """
    thermal_conductivity child of inert_particle_child.
    """
    thermophoretic_co: thermophoretic_co_cls = thermophoretic_co_cls
    """
    thermophoretic_co child of inert_particle_child.
    """
    scattering_factor: scattering_factor_cls = scattering_factor_cls
    """
    scattering_factor child of inert_particle_child.
    """
    emissivity: emissivity_cls = emissivity_cls
    """
    emissivity child of inert_particle_child.
    """
    viscosity: viscosity_cls = viscosity_cls
    """
    viscosity child of inert_particle_child.
    """
    dpm_surften: dpm_surften_cls = dpm_surften_cls
    """
    dpm_surften child of inert_particle_child.
    """
    electric_conductivity: electric_conductivity_cls = electric_conductivity_cls
    """
    electric_conductivity child of inert_particle_child.
    """
    dual_electric_conductivity: dual_electric_conductivity_cls = dual_electric_conductivity_cls
    """
    dual_electric_conductivity child of inert_particle_child.
    """
    magnetic_permeability: magnetic_permeability_cls = magnetic_permeability_cls
    """
    magnetic_permeability child of inert_particle_child.
    """
    charge_density: charge_density_cls = charge_density_cls
    """
    charge_density child of inert_particle_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .control_by import control_by as control_by_cls
from .max_number_of_steps import max_number_of_steps as max_number_of_steps_cls
from .length_scale import length_scale as length_scale_cls
from .step_length_factor import step_length_factor as step_length_factor_cls
class tracking_parameters(Group):
    """
    Main menu to control the time integration of the particle trajectory equations:
    
     - the maximum number of steps; the trajectory calculation is stopped and the particle aborted when the particle reaches this limit.
     - the length scale/step length factor; this factor is used to set the time step size for integration within a cell.
    
    """

    fluent_name = "tracking-parameters"

    child_names = \
        ['control_by', 'max_number_of_steps', 'length_scale',
         'step_length_factor']

    control_by: control_by_cls = control_by_cls
    """
    control_by child of tracking_parameters.
    """
    max_number_of_steps: max_number_of_steps_cls = max_number_of_steps_cls
    """
    max_number_of_steps child of tracking_parameters.
    """
    length_scale: length_scale_cls = length_scale_cls
    """
    length_scale child of tracking_parameters.
    """
    step_length_factor: step_length_factor_cls = step_length_factor_cls
    """
    step_length_factor child of tracking_parameters.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .max_fine_relaxations import max_fine_relaxations as max_fine_relaxations_cls
from .max_coarse_relaxations import max_coarse_relaxations as max_coarse_relaxations_cls
class flexible_cycle_paramters(Group):
    """
    'flexible_cycle_paramters' child.
    """

    fluent_name = "flexible-cycle-paramters"

    child_names = \
        ['max_fine_relaxations', 'max_coarse_relaxations']

    max_fine_relaxations: max_fine_relaxations_cls = max_fine_relaxations_cls
    """
    max_fine_relaxations child of flexible_cycle_paramters.
    """
    max_coarse_relaxations: max_coarse_relaxations_cls = max_coarse_relaxations_cls
    """
    max_coarse_relaxations child of flexible_cycle_paramters.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .face_zone import face_zone as face_zone_cls
from .normal_distance import normal_distance as normal_distance_cls
from .parametric_coordinates import parametric_coordinates as parametric_coordinates_cls
class extrude_face_zone_para(Command):
    """
    Extrude a face thread a specified distance based on a distance and a list of parametric locations between 0 and 1 (eg. 0 0.2 0.4 0.8 1.0).
    
    Parameters
    ----------
        face_zone : str
            Enter a zone name.
        normal_distance : real
            'normal_distance' child.
        parametric_coordinates : typing.List[real]
            'parametric_coordinates' child.
    
    """

    fluent_name = "extrude-face-zone-para"

    argument_names = \
        ['face_zone', 'normal_distance', 'parametric_coordinates']

    face_zone: face_zone_cls = face_zone_cls
    """
    face_zone argument of extrude_face_zone_para.
    """
    normal_distance: normal_distance_cls = normal_distance_cls
    """
    normal_distance argument of extrude_face_zone_para.
    """
    parametric_coordinates: parametric_coordinates_cls = parametric_coordinates_cls
    """
    parametric_coordinates argument of extrude_face_zone_para.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .zone_id import zone_id as zone_id_cls
class slit_face_zone(Command):
    """
    Slit a two-sided wall into two connected wall zones.
    
    Parameters
    ----------
        zone_id : int
            'zone_id' child.
    
    """

    fluent_name = "slit-face-zone"

    argument_names = \
        ['zone_id']

    zone_id: zone_id_cls = zone_id_cls
    """
    zone_id argument of slit_face_zone.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class cathode_c_init(Real):
    """
    Set initial Li+ conc. in cathode.
    """

    fluent_name = "cathode-c-init"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enable_3 import enable as enable_cls
from .turbulence_options import turbulence_options as turbulence_options_cls
class warped_face_gradient_correction(Group):
    """
    'warped_face_gradient_correction' child.
    """

    fluent_name = "warped-face-gradient-correction"

    child_names = \
        ['enable', 'turbulence_options']

    enable: enable_cls = enable_cls
    """
    enable child of warped_face_gradient_correction.
    """
    turbulence_options: turbulence_options_cls = turbulence_options_cls
    """
    turbulence_options child of warped_face_gradient_correction.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .injection_child import injection_child

class injection(NamedObject[injection_child], _CreatableNamedObjectMixin[injection_child]):
    """
    'injection' child.
    """

    fluent_name = "injection"

    child_object_type: injection_child = injection_child
    """
    child_object_type of injection.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .domain_val import domain_val as domain_val_cls
from .all_bndry_zones import all_bndry_zones as all_bndry_zones_cls
from .zone_list import zone_list as zone_list_cls
from .write_to_file import write_to_file as write_to_file_cls
from .file_name_1 import file_name as file_name_cls
from .append_data import append_data as append_data_cls
from .overwrite import overwrite as overwrite_cls
class rad_heat_trans(Command):
    """
    Print radiation heat transfer rate at boundaries.
    
    Parameters
    ----------
        domain_val : str
            'domain_val' child.
        all_bndry_zones : bool
            Select all the boundary/interior zones.
        zone_list : typing.List[str]
            'zone_list' child.
        write_to_file : bool
            'write_to_file' child.
        file_name : str
            'file_name' child.
        append_data : bool
            'append_data' child.
        overwrite : bool
            'overwrite' child.
    
    """

    fluent_name = "rad-heat-trans"

    argument_names = \
        ['domain_val', 'all_bndry_zones', 'zone_list', 'write_to_file',
         'file_name', 'append_data', 'overwrite']

    domain_val: domain_val_cls = domain_val_cls
    """
    domain_val argument of rad_heat_trans.
    """
    all_bndry_zones: all_bndry_zones_cls = all_bndry_zones_cls
    """
    all_bndry_zones argument of rad_heat_trans.
    """
    zone_list: zone_list_cls = zone_list_cls
    """
    zone_list argument of rad_heat_trans.
    """
    write_to_file: write_to_file_cls = write_to_file_cls
    """
    write_to_file argument of rad_heat_trans.
    """
    file_name: file_name_cls = file_name_cls
    """
    file_name argument of rad_heat_trans.
    """
    append_data: append_data_cls = append_data_cls
    """
    append_data argument of rad_heat_trans.
    """
    overwrite: overwrite_cls = overwrite_cls
    """
    overwrite argument of rad_heat_trans.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name_1 import name as name_cls
from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .les_spec_name import les_spec_name as les_spec_name_cls
from .rfg_number_of_modes import rfg_number_of_modes as rfg_number_of_modes_cls
from .vm_nvortices import vm_nvortices as vm_nvortices_cls
from .les_embedded_fluctuations import les_embedded_fluctuations as les_embedded_fluctuations_cls
class phase_child(Group):
    """
    'child_object_type' of phase.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread', 'les_spec_name',
         'rfg_number_of_modes', 'vm_nvortices', 'les_embedded_fluctuations']

    name: name_cls = name_cls
    """
    name child of phase_child.
    """
    geom_disable: geom_disable_cls = geom_disable_cls
    """
    geom_disable child of phase_child.
    """
    geom_dir_spec: geom_dir_spec_cls = geom_dir_spec_cls
    """
    geom_dir_spec child of phase_child.
    """
    geom_dir_x: geom_dir_x_cls = geom_dir_x_cls
    """
    geom_dir_x child of phase_child.
    """
    geom_dir_y: geom_dir_y_cls = geom_dir_y_cls
    """
    geom_dir_y child of phase_child.
    """
    geom_dir_z: geom_dir_z_cls = geom_dir_z_cls
    """
    geom_dir_z child of phase_child.
    """
    geom_levels: geom_levels_cls = geom_levels_cls
    """
    geom_levels child of phase_child.
    """
    geom_bgthread: geom_bgthread_cls = geom_bgthread_cls
    """
    geom_bgthread child of phase_child.
    """
    les_spec_name: les_spec_name_cls = les_spec_name_cls
    """
    les_spec_name child of phase_child.
    """
    rfg_number_of_modes: rfg_number_of_modes_cls = rfg_number_of_modes_cls
    """
    rfg_number_of_modes child of phase_child.
    """
    vm_nvortices: vm_nvortices_cls = vm_nvortices_cls
    """
    vm_nvortices child of phase_child.
    """
    les_embedded_fluctuations: les_embedded_fluctuations_cls = les_embedded_fluctuations_cls
    """
    les_embedded_fluctuations child of phase_child.
    """



"""Provides a module for launching utilities."""

from enum import Enum
import json
import logging
import os
from pathlib import Path
import platform
import socket
import subprocess
import tempfile
import time
from typing import Any, Dict, Optional, Union

from beartype import beartype

from ansys.fluent.core.exceptions import DisallowedValuesError, InvalidArgument
from ansys.fluent.core.fluent_connection import FluentConnection, PortNotProvided
from ansys.fluent.core.scheduler import build_parallel_options, load_machines
from ansys.fluent.core.session import _parse_server_info_file
from ansys.fluent.core.session_meshing import Meshing
from ansys.fluent.core.session_pure_meshing import PureMeshing
from ansys.fluent.core.session_solver import Solver
from ansys.fluent.core.session_solver_icing import SolverIcing
from ansys.fluent.core.utils.file_transfer_service import (
    PimFileTransferService,
    RemoteFileHandler,
)
from ansys.fluent.core.utils.fluent_version import FluentVersion
from ansys.fluent.core.utils.networking import find_remoting_ip
import ansys.platform.instancemanagement as pypim

_THIS_DIR = os.path.dirname(__file__)
_OPTIONS_FILE = os.path.join(_THIS_DIR, "fluent_launcher_options.json")
logger = logging.getLogger("pyfluent.launcher")


class InvalidPassword(ValueError):
    """Provides the error when password is invalid."""

    def __init__(self):
        super().__init__("Provide correct 'password'.")


class IpPortNotProvided(ValueError):
    """Provides the error when ip and port are not specified."""

    def __init__(self):
        super().__init__("Provide either 'ip' and 'port' or 'server_info_file_name'.")


class UnexpectedKeywordArgument(TypeError):
    """Provides the error when a valid keyword argument is not specified."""

    pass


class DockerContainerLaunchNotSupported(SystemError):
    """Provides the error when docker container launch is not supported."""

    def __init__(self):
        super().__init__("Python Docker SDK is unsupported on this system.")


def _is_windows():
    """Check if the current operating system is windows."""
    return platform.system() == "Windows"


class LaunchMode(Enum):
    """An enumeration over supported Fluent launch modes."""

    STANDALONE = 1
    PIM = 2
    CONTAINER = 3
    SLURM = 4


def check_docker_support():
    """Checks whether Python Docker SDK is supported by the current system."""
    import docker

    try:
        _ = docker.from_env()
    except docker.errors.DockerException:
        return False
    return True


def get_fluent_exe_path(**launch_argvals) -> Path:
    """Get Fluent executable path. The path is searched in the following order.

    1. ``product_version`` parameter passed with ``launch_fluent``.
    2. The latest ANSYS version from ``AWP_ROOTnnn``` environment variables.

    Returns
    -------
    Path
        Fluent executable path
    """

    def get_fluent_root(version: FluentVersion) -> Path:
        awp_root = os.environ[version.awp_var]
        return Path(awp_root) / "fluent"

    def get_exe_path(fluent_root: Path) -> Path:
        if _is_windows():
            return fluent_root / "ntbin" / "win64" / "fluent.exe"
        else:
            return fluent_root / "bin" / "fluent"

    # (DEV) "PYFLUENT_FLUENT_ROOT" environment variable
    fluent_root = os.getenv("PYFLUENT_FLUENT_ROOT")
    if fluent_root:
        return get_exe_path(Path(fluent_root))

    # Look for Fluent exe path in the following order:
    # 1. product_version parameter passed with launch_fluent
    product_version = launch_argvals.get("product_version")
    if product_version:
        return get_exe_path(get_fluent_root(FluentVersion(product_version)))

    # 2. the latest ANSYS version from AWP_ROOT environment variables
    return get_exe_path(get_fluent_root(FluentVersion.get_latest_installed()))


class FluentMode(Enum):
    """An enumeration over supported Fluent modes."""

    # Tuple: Name, Solver object type, Meshing flag, Launcher options
    MESHING_MODE = ("meshing", Meshing, True, [])
    PURE_MESHING_MODE = ("pure-meshing", PureMeshing, True, [])
    SOLVER = ("solver", Solver, False, [])
    SOLVER_ICING = ("solver-icing", SolverIcing, False, [("fluent_icing", True)])

    @staticmethod
    def get_mode(mode: str) -> "FluentMode":
        """Returns the FluentMode based on the provided mode string.

        Parameters
        ----------
        mode : str
            mode

        Returns
        -------
        FluentMode
            Fluent mode

        Raises
        ------
        DisallowedValuesError
            If an unknown mode is passed.
        """
        for m in FluentMode:
            if mode == m.value[0]:
                return m
        else:
            raise DisallowedValuesError(
                "mode", mode, ["meshing", "pure-meshing", "solver", "solver-icing"]
            )


def _get_server_info_file_name(use_tmpdir=True):
    server_info_dir = os.getenv("SERVER_INFO_DIR")
    dir_ = (
        Path(server_info_dir)
        if server_info_dir
        else tempfile.gettempdir()
        if use_tmpdir
        else Path.cwd()
    )
    fd, file_name = tempfile.mkstemp(suffix=".txt", prefix="serverinfo-", dir=str(dir_))
    os.close(fd)
    return file_name


def _get_subprocess_kwargs_for_fluent(env: Dict[str, Any], argvals) -> Dict[str, Any]:
    scheduler_options = argvals.get("scheduler_options")
    is_slurm = scheduler_options and scheduler_options["scheduler"] == "slurm"
    kwargs: Dict[str, Any] = {}
    if is_slurm:
        kwargs.update(stdout=subprocess.PIPE)
    if _is_windows():
        kwargs.update(shell=True, creationflags=subprocess.CREATE_NEW_PROCESS_GROUP)
    else:
        kwargs.update(shell=True, start_new_session=True)
    fluent_env = os.environ.copy()
    fluent_env.update({k: str(v) for k, v in env.items()})
    fluent_env["REMOTING_THROW_LAST_TUI_ERROR"] = "1"

    if not is_slurm:
        from ansys.fluent.core import INFER_REMOTING_IP

        if INFER_REMOTING_IP and not "REMOTING_SERVER_ADDRESS" in fluent_env:
            remoting_ip = find_remoting_ip()
            if remoting_ip:
                fluent_env["REMOTING_SERVER_ADDRESS"] = remoting_ip

    kwargs.update(env=fluent_env)
    return kwargs


def _build_fluent_launch_args_string(**kwargs) -> str:
    """Build Fluent's launch arguments string from keyword arguments.

    Returns
    -------
    str
        Fluent's launch arguments string.
    """
    all_options = None
    with open(_OPTIONS_FILE, encoding="utf-8") as fp:
        all_options = json.load(fp)
    launch_args_string = ""
    for k, v in all_options.items():
        argval = kwargs.get(k)
        default = v.get("default")
        if argval is None and v.get("fluent_required") is True:
            argval = default
        if argval is not None:
            allowed_values = v.get("allowed_values")
            if allowed_values and argval not in allowed_values:
                if default is not None:
                    old_argval = argval
                    argval = default
                    logger.warning(
                        f"Specified value '{old_argval}' for argument '{k}' is not an allowed value ({allowed_values}), default value '{argval}' is going to be used instead."
                    )
                else:
                    logger.warning(
                        f"{k} = {argval} is discarded as it is not an allowed value. Allowed values: {allowed_values}"
                    )
                    continue
            fluent_map = v.get("fluent_map")
            if fluent_map:
                if isinstance(argval, str):
                    json_key = argval
                else:
                    json_key = json.dumps(argval)
                argval = fluent_map[json_key]
            launch_args_string += v["fluent_format"].replace("{}", str(argval))
    addArgs = kwargs["additional_arguments"]
    if "-t" not in addArgs and "-cnf=" not in addArgs:
        parallel_options = build_parallel_options(
            load_machines(ncores=kwargs["processor_count"])
        )
        if parallel_options:
            launch_args_string += " " + parallel_options
    return launch_args_string


def _get_session_info(argvals, mode: Optional[Union[FluentMode, str, None]] = None):
    """Updates the session information."""
    if mode is None:
        mode = FluentMode.SOLVER

    if isinstance(mode, str):
        mode = FluentMode.get_mode(mode)
    new_session = mode.value[1]
    meshing_mode = mode.value[2]
    for k, v in mode.value[3]:
        argvals[k] = v

    return new_session, meshing_mode, argvals, mode


def _raise_exception_g_gu_in_windows_os(additional_arguments: str) -> None:
    """If -g or -gu is passed in Windows OS, the exception should be raised."""
    additional_arg_list = additional_arguments.split()
    if _is_windows() and (
        ("-g" in additional_arg_list) or ("-gu" in additional_arg_list)
    ):
        raise InvalidArgument("Unsupported '-g' and '-gu' on windows platform.")


def _update_launch_string_wrt_gui_options(
    launch_string: str, show_gui: Optional[bool] = None, additional_arguments: str = ""
) -> str:
    """Checks for all gui options in additional arguments and updates the launch string
    with hidden, if none of the options are met."""

    if (show_gui is False) or (
        show_gui is None and (os.getenv("PYFLUENT_SHOW_SERVER_GUI") != "1")
    ):
        if not {"-g", "-gu"} & set(additional_arguments.split()):
            launch_string += " -hidden"

    return launch_string


def _await_fluent_launch(
    server_info_file_name: str, start_timeout: int, sifile_last_mtime: float
):
    """Wait for successful fluent launch or raise an error."""
    while True:
        if Path(server_info_file_name).stat().st_mtime > sifile_last_mtime:
            time.sleep(1)
            logger.info("Fluent has been successfully launched.")
            break
        if start_timeout == 0:
            raise TimeoutError("The launch process has timed out.")
        time.sleep(1)
        start_timeout -= 1
        logger.info(f"Waiting for Fluent to launch...")
        if start_timeout >= 0:
            logger.info(f"...{start_timeout} seconds remaining")


def _get_server_info(
    server_info_file_name: str,
    ip: Optional[str] = None,
    port: Optional[int] = None,
    password: Optional[str] = None,
):
    """Get server connection information of an already running session."""
    if not (ip and port) and not server_info_file_name:
        raise IpPortNotProvided()
    if (ip or port) and server_info_file_name:
        logger.warning(
            "The ip and port will be extracted from the server-info file and their explicitly specified values will be ignored."
        )
    else:
        if server_info_file_name:
            ip, port, password = _parse_server_info_file(server_info_file_name)
        ip = ip or os.getenv("PYFLUENT_FLUENT_IP", "127.0.0.1")
        port = port or os.getenv("PYFLUENT_FLUENT_PORT")

    if not port:
        raise PortNotProvided()

    return ip, port, password


def _get_running_session_mode(
    fluent_connection: FluentConnection, mode: Optional[FluentMode] = None
):
    """Get the mode of the running session if the mode has not been mentioned
    explicitly."""
    if mode:
        session_mode = mode
    else:
        try:
            session_mode = FluentMode.get_mode(
                "solver"
                if fluent_connection.scheme_eval.scheme_eval("(cx-solver-mode?)")
                else "meshing"
            )
        except Exception as ex:
            raise InvalidPassword() from ex
    return session_mode.value[1]


def _generate_launch_string(
    argvals,
    meshing_mode: bool,
    show_gui: bool,
    additional_arguments: str,
    server_info_file_name: str,
):
    """Generates the launch string to launch fluent."""
    if _is_windows():
        exe_path = str(get_fluent_exe_path(**argvals))
        if " " in exe_path:
            exe_path = '"' + exe_path + '"'
    else:
        exe_path = str(get_fluent_exe_path(**argvals))
    launch_string = exe_path
    launch_string += _build_fluent_launch_args_string(**argvals)
    if meshing_mode:
        launch_string += " -meshing"
    if additional_arguments:
        launch_string += f" {additional_arguments}"
    if " " in server_info_file_name:
        server_info_file_name = '"' + server_info_file_name + '"'
    launch_string += f" -sifile={server_info_file_name}"
    launch_string += " -nm"
    launch_string = _update_launch_string_wrt_gui_options(
        launch_string, show_gui, additional_arguments
    )
    return launch_string


def _confirm_watchdog_start(start_watchdog, cleanup_on_exit, fluent_connection):
    """Confirm whether Fluent is running locally, and whether the Watchdog should be
    started."""
    if start_watchdog is None and cleanup_on_exit:
        host = fluent_connection.connection_properties.cortex_host
        if host == socket.gethostname():
            logger.debug(
                "Fluent running on the host machine and 'cleanup_on_exit' activated, will launch Watchdog."
            )
            start_watchdog = True
    return start_watchdog


@beartype
def _build_journal_argument(
    topy: Union[None, bool, str], journal_file_names: Union[None, str, list[str]]
) -> str:
    """Build Fluent commandline journal argument."""
    if topy and not journal_file_names:
        raise InvalidArgument(
            "Use 'journal_file_names' to specify and convert journal files."
        )
    fluent_jou_arg = ""
    if isinstance(journal_file_names, str):
        journal_file_names = [journal_file_names]
    if journal_file_names:
        fluent_jou_arg += "".join(
            [f' -i "{journal}"' for journal in journal_file_names]
        )
    if topy:
        if isinstance(topy, str):
            fluent_jou_arg += f' -topy="{topy}"'
        else:
            fluent_jou_arg += " -topy"
    return fluent_jou_arg


# pylint: disable=missing-raises-doc
class LaunchFluentError(Exception):
    """Exception class representing launch errors."""

    def __init__(self, launch_string):
        """__init__ method of LaunchFluentError class."""
        details = "\n" + "Fluent Launch string: " + launch_string
        super().__init__(details)


def _process_kwargs(kwargs):
    """Verify whether keyword arguments are valid or not.

    Parameters
    ----------
    kwargs: Any
        Provided keyword arguments.

    Raises
    ------
    UnexpectedKeywordArgument
        If an unexpected keyword argument is provided.
    """
    if kwargs:
        if "meshing_mode" in kwargs:
            raise UnexpectedKeywordArgument(
                "Use 'launch_fluent(mode='meshing')' to launch Fluent in meshing mode."
            )
        else:
            raise UnexpectedKeywordArgument(
                f"launch_fluent() got an unexpected keyword argument {next(iter(kwargs))}"
            )


def _get_fluent_launch_mode(start_container, container_dict, scheduler_options):
    """Get Fluent launch mode.

    Parameters
    ----------
    start_container: bool
        Specifies whether to launch a Fluent Docker container image.
    container_dict: dict
        Dictionary for Fluent Docker container configuration.

    Returns
    -------
    fluent_launch_mode: str
        Fluent launch mode.
    """
    if pypim.is_configured():
        fluent_launch_mode = "pim"
    elif start_container is True or (
        start_container is None
        and (container_dict or os.getenv("PYFLUENT_LAUNCH_CONTAINER") == "1")
    ):
        if check_docker_support():
            fluent_launch_mode = "container"
        else:
            raise DockerContainerLaunchNotSupported()
    elif scheduler_options and scheduler_options["scheduler"] == "slurm":
        fluent_launch_mode = "slurm"
    else:
        fluent_launch_mode = "standalone"
    return fluent_launch_mode


def _process_invalid_args(dry_run, fluent_launch_mode, argvals):
    """Get invalid arguments.

    Parameters
    ----------
    dry_run: bool
        If dry running a container start,
        ``launch_fluent()`` will return the configured ``container_dict``.
    fluent_launch_mode: str
        Fluent launch mode.
    argvals: dict
        Local arguments.
    """
    if dry_run and fluent_launch_mode != "container":
        logger.warning(
            "'dry_run' argument for 'launch_fluent' currently is only "
            "supported when starting containers."
        )
    if fluent_launch_mode != "standalone":
        arg_names = [
            "env",
            "cwd",
            "topy",
            "case_file_name",
            "lightweight_mode",
            "journal_file_names",
            "case_data_file_name",
        ]
        invalid_arg_names = list(
            filter(lambda arg_name: argvals[arg_name] is not None, arg_names)
        )
        if len(invalid_arg_names) != 0:
            invalid_str_names = ", ".join(invalid_arg_names)
            logger.warning(
                f"These specified arguments are only supported when starting "
                f"local standalone Fluent clients: {invalid_str_names}."
            )


def _get_argvals(argvals, mode):
    """Update local arguments.

    Parameters
    ----------
    argvals: dict
        Local arguments.
    mode : str
        Launch mode of Fluent to point to a specific session type.
        Options are ``"meshing"``, ``"pure-meshing"`` and ``"solver"``.

    Returns
    -------
    argvals: dict
        Updated local arguments.
    """
    new_session, meshing_mode, argvals, mode = _get_session_info(argvals, mode)
    argvals = locals().copy()
    return argvals


def launch_remote_fluent(
    session_cls,
    start_transcript: bool,
    product_version: Optional[str] = None,
    cleanup_on_exit: bool = True,
    meshing_mode: bool = False,
    dimensionality: Optional[str] = None,
    launcher_args: Optional[Dict[str, Any]] = None,
) -> Union[Meshing, PureMeshing, Solver, SolverIcing]:
    """Launch Fluent remotely using `PyPIM <https://pypim.docs.pyansys.com>`.

    When calling this method, you must ensure that you are in an
    environment where PyPIM is configured. You can use the :func:
    `pypim.is_configured <ansys.platform.instancemanagement.is_configured>`
    method to verify that PyPIM is configured.

    Parameters
    ----------
    session_cls: Union[type(Meshing), type(PureMeshing), type(Solver), type(SolverIcing)]
        Session type.
    start_transcript: bool
        Whether to start streaming the Fluent transcript in the client. The
        default is ``True``. You can stop and start the streaming of the
        Fluent transcript subsequently via method calls on the session object.
    product_version : str, optional
        Select an installed version of ANSYS. The string must be in a format like
        ``"23.2.0"`` (for 2023 R2) matching the documented version format in the
        FluentVersion class. The default is ``None``, in which case the newest installed
        version is used.
    cleanup_on_exit : bool, optional
        Whether to clean up and exit Fluent when Python exits or when garbage
        is collected for the Fluent Python instance. The default is ``True``.
    meshing_mode : bool, optional
        Whether to launch Fluent remotely in meshing mode. The default is
        ``False``.
    dimensionality : str, optional
        Geometric dimensionality of the Fluent simulation. The default is ``None``,
        in which case ``"3d"`` is used. Options are ``"3d"`` and ``"2d"``.

    Returns
    -------
    :obj:`~typing.Union` [:class:`Meshing<ansys.fluent.core.session_meshing.Meshing>`, \
    :class:`~ansys.fluent.core.session_pure_meshing.PureMeshing`, \
    :class:`~ansys.fluent.core.session_solver.Solver`, \
    :class:`~ansys.fluent.core.session_solver_icing.SolverIcing`]
        Session object.
    """
    pim = pypim.connect()
    instance = pim.create_instance(
        product_name="fluent-meshing"
        if meshing_mode
        else "fluent-2ddp"
        if dimensionality == "2d"
        else "fluent-3ddp",
        product_version=product_version,
    )
    instance.wait_for_ready()
    # nb pymapdl sets max msg len here:
    channel = instance.build_grpc_channel()

    fluent_connection = FluentConnection(
        channel=channel,
        cleanup_on_exit=cleanup_on_exit,
        remote_instance=instance,
        start_transcript=start_transcript,
        launcher_args=launcher_args,
    )

    remote_file_handler = RemoteFileHandler(
        transfer_service=PimFileTransferService(
            pim_instance=fluent_connection._remote_instance
        )
    )

    return session_cls(
        fluent_connection=fluent_connection, remote_file_handler=remote_file_handler
    )



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .solar_model import solar_model as solar_model_cls
from .sun_direction_vector import sun_direction_vector as sun_direction_vector_cls
from .illumination_parameters import illumination_parameters as illumination_parameters_cls
from .quad_tree_parameters import quad_tree_parameters as quad_tree_parameters_cls
from .ground_reflectivity import ground_reflectivity as ground_reflectivity_cls
from .scattering_fraction import scattering_fraction as scattering_fraction_cls
from .solar_on_adjacent_fluid import solar_on_adjacent_fluid as solar_on_adjacent_fluid_cls
from .direction_from_solar_calculator import direction_from_solar_calculator as direction_from_solar_calculator_cls
from .solar_load_frequency import solar_load_frequency as solar_load_frequency_cls
from .solar_calculator import solar_calculator as solar_calculator_cls
from .apply_full_solar_irradiation import apply_full_solar_irradiation as apply_full_solar_irradiation_cls
from .autoread_solar_data import autoread_solar_data as autoread_solar_data_cls
from .autosave_solar_data import autosave_solar_data as autosave_solar_data_cls
from .solar_on_demand import solar_on_demand as solar_on_demand_cls
class solar_load(Group):
    """
    'solar_load' child.
    """

    fluent_name = "solar-load"

    child_names = \
        ['solar_model', 'sun_direction_vector', 'illumination_parameters',
         'quad_tree_parameters', 'ground_reflectivity', 'scattering_fraction',
         'solar_on_adjacent_fluid', 'direction_from_solar_calculator',
         'solar_load_frequency', 'solar_calculator',
         'apply_full_solar_irradiation', 'autoread_solar_data',
         'autosave_solar_data']

    solar_model: solar_model_cls = solar_model_cls
    """
    solar_model child of solar_load.
    """
    sun_direction_vector: sun_direction_vector_cls = sun_direction_vector_cls
    """
    sun_direction_vector child of solar_load.
    """
    illumination_parameters: illumination_parameters_cls = illumination_parameters_cls
    """
    illumination_parameters child of solar_load.
    """
    quad_tree_parameters: quad_tree_parameters_cls = quad_tree_parameters_cls
    """
    quad_tree_parameters child of solar_load.
    """
    ground_reflectivity: ground_reflectivity_cls = ground_reflectivity_cls
    """
    ground_reflectivity child of solar_load.
    """
    scattering_fraction: scattering_fraction_cls = scattering_fraction_cls
    """
    scattering_fraction child of solar_load.
    """
    solar_on_adjacent_fluid: solar_on_adjacent_fluid_cls = solar_on_adjacent_fluid_cls
    """
    solar_on_adjacent_fluid child of solar_load.
    """
    direction_from_solar_calculator: direction_from_solar_calculator_cls = direction_from_solar_calculator_cls
    """
    direction_from_solar_calculator child of solar_load.
    """
    solar_load_frequency: solar_load_frequency_cls = solar_load_frequency_cls
    """
    solar_load_frequency child of solar_load.
    """
    solar_calculator: solar_calculator_cls = solar_calculator_cls
    """
    solar_calculator child of solar_load.
    """
    apply_full_solar_irradiation: apply_full_solar_irradiation_cls = apply_full_solar_irradiation_cls
    """
    apply_full_solar_irradiation child of solar_load.
    """
    autoread_solar_data: autoread_solar_data_cls = autoread_solar_data_cls
    """
    autoread_solar_data child of solar_load.
    """
    autosave_solar_data: autosave_solar_data_cls = autosave_solar_data_cls
    """
    autosave_solar_data child of solar_load.
    """
    command_names = \
        ['solar_on_demand']

    solar_on_demand: solar_on_demand_cls = solar_on_demand_cls
    """
    solar_on_demand command of solar_load.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enable_4 import enable as enable_cls
from .mode import mode as mode_cls
from .disk import disk as disk_cls
class virtual_blade_model(Group):
    """
    Enter the vbm model menu.
    """

    fluent_name = "virtual-blade-model"

    child_names = \
        ['enable', 'mode', 'disk']

    enable: enable_cls = enable_cls
    """
    enable child of virtual_blade_model.
    """
    mode: mode_cls = mode_cls
    """
    mode child of virtual_blade_model.
    """
    disk: disk_cls = disk_cls
    """
    disk child of virtual_blade_model.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .case_file import case_file as case_file_cls
from .across_zones import across_zones as across_zones_cls
from .method_2 import method as method_cls
from .load_vector import load_vector as load_vector_cls
from .pre_test import pre_test as pre_test_cls
class auto(Group):
    """
    Enter the menu to set auto partition parameters.
    """

    fluent_name = "auto"

    child_names = \
        ['case_file', 'across_zones', 'method', 'load_vector', 'pre_test']

    case_file: case_file_cls = case_file_cls
    """
    case_file child of auto.
    """
    across_zones: across_zones_cls = across_zones_cls
    """
    across_zones child of auto.
    """
    method: method_cls = method_cls
    """
    method child of auto.
    """
    load_vector: load_vector_cls = load_vector_cls
    """
    load_vector child of auto.
    """
    pre_test: pre_test_cls = pre_test_cls
    """
    pre_test child of auto.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .delete_1 import delete as delete_cls
from .list import list as list_cls
from .list_properties_1 import list_properties as list_properties_cls
from .make_a_copy import make_a_copy as make_a_copy_cls
from .pressure_outlet_child import pressure_outlet_child

class pressure_outlet(NamedObject[pressure_outlet_child], _NonCreatableNamedObjectMixin[pressure_outlet_child]):
    """
    'pressure_outlet' child.
    """

    fluent_name = "pressure-outlet"

    command_names = \
        ['delete', 'list', 'list_properties', 'make_a_copy']

    delete: delete_cls = delete_cls
    """
    delete command of pressure_outlet.
    """
    list: list_cls = list_cls
    """
    list command of pressure_outlet.
    """
    list_properties: list_properties_cls = list_properties_cls
    """
    list_properties command of pressure_outlet.
    """
    make_a_copy: make_a_copy_cls = make_a_copy_cls
    """
    make_a_copy command of pressure_outlet.
    """
    child_object_type: pressure_outlet_child = pressure_outlet_child
    """
    child_object_type of pressure_outlet.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .direction_option import direction_option as direction_option_cls
from .vector import vector as vector_cls
from .point import point as point_cls
from .axis_label import axis_label as axis_label_cls
class axis_to(Group):
    """
    'axis_to' child.
    """

    fluent_name = "axis-to"

    child_names = \
        ['direction_option', 'vector', 'point', 'axis_label']

    direction_option: direction_option_cls = direction_option_cls
    """
    direction_option child of axis_to.
    """
    vector: vector_cls = vector_cls
    """
    vector child of axis_to.
    """
    point: point_cls = point_cls
    """
    point child of axis_to.
    """
    axis_label: axis_label_cls = axis_label_cls
    """
    axis_label child of axis_to.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class specify_gradient_method(Integer):
    """
    Set gradient method for solver stability and accuracy.
    """

    fluent_name = "specify-gradient-method"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .change_curr_sample import change_curr_sample as change_curr_sample_cls
from .sample import sample as sample_cls
class weighting_variable(Command):
    """
    Choose the weighting variable for the averaging in each bin in the data reduction.
    
    Parameters
    ----------
        change_curr_sample : bool
            'change_curr_sample' child.
        sample : str
            'sample' child.
    
    """

    fluent_name = "weighting-variable"

    argument_names = \
        ['change_curr_sample', 'sample']

    change_curr_sample: change_curr_sample_cls = change_curr_sample_cls
    """
    change_curr_sample argument of weighting_variable.
    """
    sample: sample_cls = sample_cls
    """
    sample argument of weighting_variable.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class export:
    fluent_name = ...
    child_names = ...
    sc_def_file_settings = ...
    settings = ...
    command_names = ...

    def abaqus(self, name: str, surface_name_list: List[str], structural_analysis: bool, write_loads: bool, loads: List[str]):
        """
        Write an ABAQUS file.
        
        Parameters
        ----------
            name : str
                'name' child.
            surface_name_list : typing.List[str]
                'surface_name_list' child.
            structural_analysis : bool
                'structural_analysis' child.
            write_loads : bool
                'write_loads' child.
            loads : typing.List[str]
                'loads' child.
        
        """

    def mechanical_apdl(self, name: str, thread_name_list: List[str]):
        """
        Write an Mechanical APDL file.
        
        Parameters
        ----------
            name : str
                'name' child.
            thread_name_list : typing.List[str]
                'thread_name_list' child.
        
        """

    def mechanical_apdl_input(self, name: str, surface_name_list: List[str], structural_analysis: bool, write_loads: bool, loads: List[str]):
        """
        Write an Mechanical APDL Input file.
        
        Parameters
        ----------
            name : str
                'name' child.
            surface_name_list : typing.List[str]
                'surface_name_list' child.
            structural_analysis : bool
                'structural_analysis' child.
            write_loads : bool
                'write_loads' child.
            loads : typing.List[str]
                'loads' child.
        
        """

    def custom_heat_flux(self, name: str, wall_function: bool, surface_name_list: List[str]):
        """
        Write a generic file for heat transfer.
        
        Parameters
        ----------
            name : str
                'name' child.
            wall_function : bool
                'wall_function' child.
            surface_name_list : typing.List[str]
                'surface_name_list' child.
        
        """

    def icemcfd_for_icepak(self, name: str):
        """
        Write a binary ICEMCFD domain file.
        
        Parameters
        ----------
            name : str
                'name' child.
        
        """

    def fast_mesh(self, name: str):
        """
        Write a FAST/Plot3D unstructured mesh file.
        
        Parameters
        ----------
            name : str
                'name' child.
        
        """

    def fast_solution(self, name: str):
        """
        Write a FAST/Plot3D unstructured solution file.
        
        Parameters
        ----------
            name : str
                'name' child.
        
        """

    def fast_velocity(self, name: str):
        """
        Write a FAST/Plot3D unstructured vector function file.
        
        Parameters
        ----------
            name : str
                'name' child.
        
        """

    def taitherm(self, name: str, surface_name_list: List[str], wall_function: bool, htc_on_walls: bool):
        """
        Write a TAITherm file.
        
        Parameters
        ----------
            name : str
                'name' child.
            surface_name_list : typing.List[str]
                'surface_name_list' child.
            wall_function : bool
                'wall_function' child.
            htc_on_walls : bool
                'htc_on_walls' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .setup_reduction import setup_reduction as setup_reduction_cls
from .pick_sample_to_reduce import pick_sample_to_reduce as pick_sample_to_reduce_cls
from .reduce_picked_sample import reduce_picked_sample as reduce_picked_sample_cls
class reduction(Group):
    """
    'reduction' child.
    """

    fluent_name = "reduction"

    child_names = \
        ['setup_reduction']

    setup_reduction: setup_reduction_cls = setup_reduction_cls
    """
    setup_reduction child of reduction.
    """
    command_names = \
        ['pick_sample_to_reduce', 'reduce_picked_sample']

    pick_sample_to_reduce: pick_sample_to_reduce_cls = pick_sample_to_reduce_cls
    """
    pick_sample_to_reduce command of reduction.
    """
    reduce_picked_sample: reduce_picked_sample_cls = reduce_picked_sample_cls
    """
    reduce_picked_sample command of reduction.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class display_states:
    fluent_name = ...
    command_names = ...

    def list(self, ):
        """
        'list' command.
        """

    def use_active(self, state_name: str):
        """
        'use_active' command.
        
        Parameters
        ----------
            state_name : str
                'state_name' child.
        
        """

    def restore_state(self, state_name: str):
        """
        Apply a display state to the active window.
        
        Parameters
        ----------
            state_name : str
                'state_name' child.
        
        """

    def copy(self, state_name: str):
        """
        Create a new display state with settings copied from an existing display state.
        
        Parameters
        ----------
            state_name : str
                'state_name' child.
        
        """

    def read(self, file_name: str):
        """
        Read display states from a file.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
        
        """

    def write(self, file_name: str, state_name: List[str]):
        """
        Write display states to a file.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
            state_name : typing.List[str]
                'state_name' child.
        
        """

    <class 'ansys.fluent.core.solver.flobject.child_object_type'> = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .xy_plot import xy_plot as xy_plot_cls
from .histogram import histogram as histogram_cls
from .cumulative_plot import cumulative_plot as cumulative_plot_cls
class plot(Group):
    """
    'plot' child.
    """

    fluent_name = "plot"

    child_names = \
        ['xy_plot', 'histogram', 'cumulative_plot']

    xy_plot: xy_plot_cls = xy_plot_cls
    """
    xy_plot child of plot.
    """
    histogram: histogram_cls = histogram_cls
    """
    histogram child of plot.
    """
    cumulative_plot: cumulative_plot_cls = cumulative_plot_cls
    """
    cumulative_plot child of plot.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .field_name_1 import field_name as field_name_cls
from .data_source import data_source as data_source_cls
from .range_options import range_options as range_options_cls
from .rendering_quality import rendering_quality as rendering_quality_cls
from .color_density import color_density as color_density_cls
from .colormap_options import colormap_options as colormap_options_cls
from .cell_zones_3 import cell_zones as cell_zones_cls
class home_options(Group):
    """
    'home_options' child.
    """

    fluent_name = "home-options"

    child_names = \
        ['field_name', 'data_source', 'range_options', 'rendering_quality',
         'color_density', 'colormap_options', 'cell_zones']

    field_name: field_name_cls = field_name_cls
    """
    field_name child of home_options.
    """
    data_source: data_source_cls = data_source_cls
    """
    data_source child of home_options.
    """
    range_options: range_options_cls = range_options_cls
    """
    range_options child of home_options.
    """
    rendering_quality: rendering_quality_cls = rendering_quality_cls
    """
    rendering_quality child of home_options.
    """
    color_density: color_density_cls = color_density_cls
    """
    color_density child of home_options.
    """
    colormap_options: colormap_options_cls = colormap_options_cls
    """
    colormap_options child of home_options.
    """
    cell_zones: cell_zones_cls = cell_zones_cls
    """
    cell_zones child of home_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .x import x as x_cls
from .x_2 import x_2 as x_2_cls
from .y import y as y_cls
from .y_2 import y_2 as y_2_cls
from .z import z as z_cls
from .z_2 import z_2 as z_2_cls
from .magnitude import magnitude as magnitude_cls
class angular_velocity(Group):
    """
    'angular_velocity' child.
    """

    fluent_name = "angular-velocity"

    child_names = \
        ['x', 'x_2', 'y', 'y_2', 'z', 'z_2', 'magnitude']

    x: x_cls = x_cls
    """
    x child of angular_velocity.
    """
    x_2: x_2_cls = x_2_cls
    """
    x_2 child of angular_velocity.
    """
    y: y_cls = y_cls
    """
    y child of angular_velocity.
    """
    y_2: y_2_cls = y_2_cls
    """
    y_2 child of angular_velocity.
    """
    z: z_cls = z_cls
    """
    z child of angular_velocity.
    """
    z_2: z_2_cls = z_2_cls
    """
    z_2 child of angular_velocity.
    """
    magnitude: magnitude_cls = magnitude_cls
    """
    magnitude child of angular_velocity.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class named_expressions_child:
    fluent_name = ...
    child_names = ...
    name = ...
    definition = ...
    description = ...
    parameterid = ...
    parametername = ...
    unit = ...
    input_parameter = ...
    output_parameter = ...
    def get_value(self, ):
        """
        'get_value' query.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .multiphase_options import multiphase_options as multiphase_options_cls
from .turbulence_multiphase_models import turbulence_multiphase_models as turbulence_multiphase_models_cls
from .rsm_multiphase_models import rsm_multiphase_models as rsm_multiphase_models_cls
from .subgrid_turbulence_contribution_aiad import subgrid_turbulence_contribution_aiad as subgrid_turbulence_contribution_aiad_cls
class multiphase_turbulence(Group):
    """
    'multiphase_turbulence' child.
    """

    fluent_name = "multiphase-turbulence"

    child_names = \
        ['multiphase_options', 'turbulence_multiphase_models',
         'rsm_multiphase_models', 'subgrid_turbulence_contribution_aiad']

    multiphase_options: multiphase_options_cls = multiphase_options_cls
    """
    multiphase_options child of multiphase_turbulence.
    """
    turbulence_multiphase_models: turbulence_multiphase_models_cls = turbulence_multiphase_models_cls
    """
    turbulence_multiphase_models child of multiphase_turbulence.
    """
    rsm_multiphase_models: rsm_multiphase_models_cls = rsm_multiphase_models_cls
    """
    rsm_multiphase_models child of multiphase_turbulence.
    """
    subgrid_turbulence_contribution_aiad: subgrid_turbulence_contribution_aiad_cls = subgrid_turbulence_contribution_aiad_cls
    """
    subgrid_turbulence_contribution_aiad child of multiphase_turbulence.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class transparency_options:
    fluent_name = ...
    child_names = ...
    settings = ...
    command_names = ...

    def reset(self, ):
        """
        'reset' command.
        """

    def invert(self, ):
        """
        'invert' command.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#
# pylint: disable=line-too-long

from ansys.fluent.core.services.datamodel_se import (
    PyMenu,
    PyParameter,
    PyTextual,
    PyNumerical,
    PyDictionary,
    PyNamedObjectContainer,
    PyCommand,
    PyQuery
)


class Root(PyMenu):
    """
    Singleton Root.
    """
    def __init__(self, service, rules, path):
        self.AssemblyNode = self.__class__.AssemblyNode(service, rules, path + [("AssemblyNode", "")])
        self.Mirror = self.__class__.Mirror(service, rules, path + [("Mirror", "")])
        self.Node = self.__class__.Node(service, rules, path + [("Node", "")])
        self.ObjectSetting = self.__class__.ObjectSetting(service, rules, path + [("ObjectSetting", "")])
        self.Refaceting = self.__class__.Refaceting(service, rules, path + [("Refaceting", "")])
        self.Rotate = self.__class__.Rotate(service, rules, path + [("Rotate", "")])
        self.RotateAboutAxis = self.__class__.RotateAboutAxis(service, rules, path + [("RotateAboutAxis", "")])
        self.Scaling = self.__class__.Scaling(service, rules, path + [("Scaling", "")])
        self.Transform = self.__class__.Transform(service, rules, path + [("Transform", "")])
        self.TransformBase = self.__class__.TransformBase(service, rules, path + [("TransformBase", "")])
        self.Translate = self.__class__.Translate(service, rules, path + [("Translate", "")])
        self.GlobalSettings = self.__class__.GlobalSettings(service, rules, path + [("GlobalSettings", "")])
        self.MeshingOperations = self.__class__.MeshingOperations(service, rules, path + [("MeshingOperations", "")])
        self.ObjectSettingOperations = self.__class__.ObjectSettingOperations(service, rules, path + [("ObjectSettingOperations", "")])
        self.RefacetingOperations = self.__class__.RefacetingOperations(service, rules, path + [("RefacetingOperations", "")])
        self.TransformOperations = self.__class__.TransformOperations(service, rules, path + [("TransformOperations", "")])
        self.AppendFmdFiles = self.__class__.AppendFmdFiles(service, rules, "AppendFmdFiles", path)
        self.ChangeFileLengthUnit = self.__class__.ChangeFileLengthUnit(service, rules, "ChangeFileLengthUnit", path)
        self.ChangeLengthUnit = self.__class__.ChangeLengthUnit(service, rules, "ChangeLengthUnit", path)
        self.CreateObjForEachPart = self.__class__.CreateObjForEachPart(service, rules, "CreateObjForEachPart", path)
        self.CreateObjects = self.__class__.CreateObjects(service, rules, "CreateObjects", path)
        self.Delete = self.__class__.Delete(service, rules, "Delete", path)
        self.DeletePaths = self.__class__.DeletePaths(service, rules, "DeletePaths", path)
        self.InitializeTemplate = self.__class__.InitializeTemplate(service, rules, "InitializeTemplate", path)
        self.InputFileChanged = self.__class__.InputFileChanged(service, rules, "InputFileChanged", path)
        self.ListMeshingOperations = self.__class__.ListMeshingOperations(service, rules, "ListMeshingOperations", path)
        self.LoadFmdFile = self.__class__.LoadFmdFile(service, rules, "LoadFmdFile", path)
        self.LoadTemplate = self.__class__.LoadTemplate(service, rules, "LoadTemplate", path)
        self.MoveCADComponentsToNewObject = self.__class__.MoveCADComponentsToNewObject(service, rules, "MoveCADComponentsToNewObject", path)
        self.MoveToNewSubobject = self.__class__.MoveToNewSubobject(service, rules, "MoveToNewSubobject", path)
        self.MoveToObject = self.__class__.MoveToObject(service, rules, "MoveToObject", path)
        self.RedoAllTransforms = self.__class__.RedoAllTransforms(service, rules, "RedoAllTransforms", path)
        self.ResetTemplate = self.__class__.ResetTemplate(service, rules, "ResetTemplate", path)
        self.SaveFmdFile = self.__class__.SaveFmdFile(service, rules, "SaveFmdFile", path)
        self.SaveTemplate = self.__class__.SaveTemplate(service, rules, "SaveTemplate", path)
        self.UndoAllTransforms = self.__class__.UndoAllTransforms(service, rules, "UndoAllTransforms", path)
        super().__init__(service, rules, path)

    class AssemblyNode(PyNamedObjectContainer):
        """
        .
        """
        class _AssemblyNode(PyMenu):
            """
            Singleton _AssemblyNode.
            """
            def __init__(self, service, rules, path):
                self.Refaceting = self.__class__.Refaceting(service, rules, path + [("Refaceting", "")])
                self.Children = self.__class__.Children(service, rules, path + [("Children", "")])
                self.Context = self.__class__.Context(service, rules, path + [("Context", "")])
                self.EdgeExtraction = self.__class__.EdgeExtraction(service, rules, path + [("EdgeExtraction", "")])
                self.FeatureAngle = self.__class__.FeatureAngle(service, rules, path + [("FeatureAngle", "")])
                self.IsChildrenSettingsChanged = self.__class__.IsChildrenSettingsChanged(service, rules, path + [("IsChildrenSettingsChanged", "")])
                self.KeyId = self.__class__.KeyId(service, rules, path + [("KeyId", "")])
                self.MergeChildren = self.__class__.MergeChildren(service, rules, path + [("MergeChildren", "")])
                self.Name = self.__class__.Name(service, rules, path + [("Name", "")])
                self.OneZonePer = self.__class__.OneZonePer(service, rules, path + [("OneZonePer", "")])
                self.Parent = self.__class__.Parent(service, rules, path + [("Parent", "")])
                self.PrefixObjectName = self.__class__.PrefixObjectName(service, rules, path + [("PrefixObjectName", "")])
                self.RefacetOperation = self.__class__.RefacetOperation(service, rules, path + [("RefacetOperation", "")])
                self.Transformations = self.__class__.Transformations(service, rules, path + [("Transformations", "")])
                self._name_ = self.__class__._name_(service, rules, path + [("_name_", "")])
                self.ChangeChildrenSettings = self.__class__.ChangeChildrenSettings(service, rules, "ChangeChildrenSettings", path)
                self.Copy = self.__class__.Copy(service, rules, "Copy", path)
                self.CreateChild = self.__class__.CreateChild(service, rules, "CreateChild", path)
                self.Move = self.__class__.Move(service, rules, "Move", path)
                self.ReFacet = self.__class__.ReFacet(service, rules, "ReFacet", path)
                self.ReFacetNow = self.__class__.ReFacetNow(service, rules, "ReFacetNow", path)
                self.Rename = self.__class__.Rename(service, rules, "Rename", path)
                super().__init__(service, rules, path)

            class Refaceting(PyMenu):
                """
                Singleton Refaceting.
                """
                def __init__(self, service, rules, path):
                    self.Deviation = self.__class__.Deviation(service, rules, path + [("Deviation", "")])
                    self.MaxSize = self.__class__.MaxSize(service, rules, path + [("MaxSize", "")])
                    self.NormalAngle = self.__class__.NormalAngle(service, rules, path + [("NormalAngle", "")])
                    self.Refacet = self.__class__.Refacet(service, rules, path + [("Refacet", "")])
                    super().__init__(service, rules, path)

                class Deviation(PyNumerical):
                    """
                    Parameter Deviation of value type float.
                    """
                    pass

                class MaxSize(PyNumerical):
                    """
                    Parameter MaxSize of value type float.
                    """
                    pass

                class NormalAngle(PyNumerical):
                    """
                    Parameter NormalAngle of value type float.
                    """
                    pass

                class Refacet(PyParameter):
                    """
                    Parameter Refacet of value type bool.
                    """
                    pass

            class Children(PyTextual):
                """
                Parameter Children of value type List[str].
                """
                pass

            class Context(PyNumerical):
                """
                Parameter Context of value type int.
                """
                pass

            class EdgeExtraction(PyTextual):
                """
                Parameter EdgeExtraction of value type str.
                """
                pass

            class FeatureAngle(PyNumerical):
                """
                Parameter FeatureAngle of value type float.
                """
                pass

            class IsChildrenSettingsChanged(PyParameter):
                """
                Parameter IsChildrenSettingsChanged of value type bool.
                """
                pass

            class KeyId(PyNumerical):
                """
                Parameter KeyId of value type int.
                """
                pass

            class MergeChildren(PyParameter):
                """
                Parameter MergeChildren of value type bool.
                """
                pass

            class Name(PyTextual):
                """
                Parameter Name of value type str.
                """
                pass

            class OneZonePer(PyTextual):
                """
                Parameter OneZonePer of value type str.
                """
                pass

            class Parent(PyTextual):
                """
                Parameter Parent of value type str.
                """
                pass

            class PrefixObjectName(PyParameter):
                """
                Parameter PrefixObjectName of value type bool.
                """
                pass

            class RefacetOperation(PyTextual):
                """
                Parameter RefacetOperation of value type str.
                """
                pass

            class Transformations(PyTextual):
                """
                Parameter Transformations of value type List[str].
                """
                pass

            class _name_(PyTextual):
                """
                Parameter _name_ of value type str.
                """
                pass

            class ChangeChildrenSettings(PyCommand):
                """
                Command ChangeChildrenSettings.


                Returns
                -------
                bool
                """
                pass

            class Copy(PyCommand):
                """
                Command Copy.

                Parameters
                ----------
                Paths : List[str]

                Returns
                -------
                bool
                """
                pass

            class CreateChild(PyCommand):
                """
                Command CreateChild.

                Parameters
                ----------
                ChildName : str

                Returns
                -------
                bool
                """
                pass

            class Move(PyCommand):
                """
                Command Move.

                Parameters
                ----------
                Paths : List[str]

                Returns
                -------
                bool
                """
                pass

            class ReFacet(PyCommand):
                """
                Command ReFacet.

                Parameters
                ----------
                Deviation : float
                NormalAngle : float
                MaxSize : float

                Returns
                -------
                bool
                """
                pass

            class ReFacetNow(PyCommand):
                """
                Command ReFacetNow.


                Returns
                -------
                bool
                """
                pass

            class Rename(PyCommand):
                """
                Command Rename.

                Parameters
                ----------
                NewName : str

                Returns
                -------
                bool
                """
                pass

        def __getitem__(self, key: str) -> _AssemblyNode:
            return super().__getitem__(key)

    class Mirror(PyNamedObjectContainer):
        """
        .
        """
        class _Mirror(PyMenu):
            """
            Singleton _Mirror.
            """
            def __init__(self, service, rules, path):
                self.Applied = self.__class__.Applied(service, rules, path + [("Applied", "")])
                self.Children = self.__class__.Children(service, rules, path + [("Children", "")])
                self.Context = self.__class__.Context(service, rules, path + [("Context", "")])
                self.Global = self.__class__.Global(service, rules, path + [("Global", "")])
                self.MirrorAbout = self.__class__.MirrorAbout(service, rules, path + [("MirrorAbout", "")])
                self.Name = self.__class__.Name(service, rules, path + [("Name", "")])
                self.Type = self.__class__.Type(service, rules, path + [("Type", "")])
                self._name_ = self.__class__._name_(service, rules, path + [("_name_", "")])
                self.Add = self.__class__.Add(service, rules, "Add", path)
                self.Apply = self.__class__.Apply(service, rules, "Apply", path)
                self.Remove = self.__class__.Remove(service, rules, "Remove", path)
                self.Rename = self.__class__.Rename(service, rules, "Rename", path)
                self.Undo = self.__class__.Undo(service, rules, "Undo", path)
                self.Update = self.__class__.Update(service, rules, "Update", path)
                super().__init__(service, rules, path)

            class Applied(PyParameter):
                """
                Parameter Applied of value type bool.
                """
                pass

            class Children(PyTextual):
                """
                Parameter Children of value type List[str].
                """
                pass

            class Context(PyNumerical):
                """
                Parameter Context of value type int.
                """
                pass

            class Global(PyTextual):
                """
                Parameter Global of value type str.
                """
                pass

            class MirrorAbout(PyTextual):
                """
                Parameter MirrorAbout of value type str.
                """
                pass

            class Name(PyTextual):
                """
                Parameter Name of value type str.
                """
                pass

            class Type(PyTextual):
                """
                Parameter Type of value type str.
                """
                pass

            class _name_(PyTextual):
                """
                Parameter _name_ of value type str.
                """
                pass

            class Add(PyCommand):
                """
                Command Add.

                Parameters
                ----------
                Paths : List[str]

                Returns
                -------
                bool
                """
                pass

            class Apply(PyCommand):
                """
                Command Apply.


                Returns
                -------
                bool
                """
                pass

            class Remove(PyCommand):
                """
                Command Remove.

                Parameters
                ----------
                Paths : List[str]

                Returns
                -------
                bool
                """
                pass

            class Rename(PyCommand):
                """
                Command Rename.

                Parameters
                ----------
                NewName : str

                Returns
                -------
                bool
                """
                pass

            class Undo(PyCommand):
                """
                Command Undo.


                Returns
                -------
                bool
                """
                pass

            class Update(PyCommand):
                """
                Command Update.


                Returns
                -------
                bool
                """
                pass

        def __getitem__(self, key: str) -> _Mirror:
            return super().__getitem__(key)

    class Node(PyNamedObjectContainer):
        """
        .
        """
        class _Node(PyMenu):
            """
            Singleton _Node.
            """
            def __init__(self, service, rules, path):
                self.Children = self.__class__.Children(service, rules, path + [("Children", "")])
                self.Context = self.__class__.Context(service, rules, path + [("Context", "")])
                self.KeyId = self.__class__.KeyId(service, rules, path + [("KeyId", "")])
                self.Name = self.__class__.Name(service, rules, path + [("Name", "")])
                self.ObjectSetting = self.__class__.ObjectSetting(service, rules, path + [("ObjectSetting", "")])
                self.Parent = self.__class__.Parent(service, rules, path + [("Parent", "")])
                self.RefacetOperation = self.__class__.RefacetOperation(service, rules, path + [("RefacetOperation", "")])
                self.Transformations = self.__class__.Transformations(service, rules, path + [("Transformations", "")])
                self.Updated = self.__class__.Updated(service, rules, path + [("Updated", "")])
                self._name_ = self.__class__._name_(service, rules, path + [("_name_", "")])
                self.Copy = self.__class__.Copy(service, rules, "Copy", path)
                self.CreateChild = self.__class__.CreateChild(service, rules, "CreateChild", path)
                self.Move = self.__class__.Move(service, rules, "Move", path)
                self.Rename = self.__class__.Rename(service, rules, "Rename", path)
                self.WildcardCopy = self.__class__.WildcardCopy(service, rules, "WildcardCopy", path)
                super().__init__(service, rules, path)

            class Children(PyTextual):
                """
                Parameter Children of value type List[str].
                """
                pass

            class Context(PyNumerical):
                """
                Parameter Context of value type int.
                """
                pass

            class KeyId(PyNumerical):
                """
                Parameter KeyId of value type int.
                """
                pass

            class Name(PyTextual):
                """
                Parameter Name of value type str.
                """
                pass

            class ObjectSetting(PyTextual):
                """
                Parameter ObjectSetting of value type str.
                """
                pass

            class Parent(PyTextual):
                """
                Parameter Parent of value type str.
                """
                pass

            class RefacetOperation(PyTextual):
                """
                Parameter RefacetOperation of value type str.
                """
                pass

            class Transformations(PyTextual):
                """
                Parameter Transformations of value type List[str].
                """
                pass

            class Updated(PyParameter):
                """
                Parameter Updated of value type bool.
                """
                pass

            class _name_(PyTextual):
                """
                Parameter _name_ of value type str.
                """
                pass

            class Copy(PyCommand):
                """
                Command Copy.

                Parameters
                ----------
                Paths : List[str]

                Returns
                -------
                bool
                """
                pass

            class CreateChild(PyCommand):
                """
                Command CreateChild.

                Parameters
                ----------
                ChildName : str

                Returns
                -------
                bool
                """
                pass

            class Move(PyCommand):
                """
                Command Move.

                Parameters
                ----------
                Paths : List[str]

                Returns
                -------
                bool
                """
                pass

            class Rename(PyCommand):
                """
                Command Rename.

                Parameters
                ----------
                NewName : str

                Returns
                -------
                bool
                """
                pass

            class WildcardCopy(PyCommand):
                """
                Command WildcardCopy.

                Parameters
                ----------
                Pattern : str

                Returns
                -------
                bool
                """
                pass

        def __getitem__(self, key: str) -> _Node:
            return super().__getitem__(key)

    class ObjectSetting(PyNamedObjectContainer):
        """
        .
        """
        class _ObjectSetting(PyMenu):
            """
            Singleton _ObjectSetting.
            """
            def __init__(self, service, rules, path):
                self.Children = self.__class__.Children(service, rules, path + [("Children", "")])
                self.Context = self.__class__.Context(service, rules, path + [("Context", "")])
                self.EdgeExtraction = self.__class__.EdgeExtraction(service, rules, path + [("EdgeExtraction", "")])
                self.FeatureAngle = self.__class__.FeatureAngle(service, rules, path + [("FeatureAngle", "")])
                self.MergeChildren = self.__class__.MergeChildren(service, rules, path + [("MergeChildren", "")])
                self.Name = self.__class__.Name(service, rules, path + [("Name", "")])
                self.OneZonePer = self.__class__.OneZonePer(service, rules, path + [("OneZonePer", "")])
                self.PrefixObjectName = self.__class__.PrefixObjectName(service, rules, path + [("PrefixObjectName", "")])
                self.UseDefaultSettings = self.__class__.UseDefaultSettings(service, rules, path + [("UseDefaultSettings", "")])
                self._name_ = self.__class__._name_(service, rules, path + [("_name_", "")])
                self.Add = self.__class__.Add(service, rules, "Add", path)
                self.Remove = self.__class__.Remove(service, rules, "Remove", path)
                self.Rename = self.__class__.Rename(service, rules, "Rename", path)
                super().__init__(service, rules, path)

            class Children(PyTextual):
                """
                Parameter Children of value type List[str].
                """
                pass

            class Context(PyNumerical):
                """
                Parameter Context of value type int.
                """
                pass

            class EdgeExtraction(PyTextual):
                """
                Parameter EdgeExtraction of value type str.
                """
                pass

            class FeatureAngle(PyNumerical):
                """
                Parameter FeatureAngle of value type float.
                """
                pass

            class MergeChildren(PyParameter):
                """
                Parameter MergeChildren of value type bool.
                """
                pass

            class Name(PyTextual):
                """
                Parameter Name of value type str.
                """
                pass

            class OneZonePer(PyTextual):
                """
                Parameter OneZonePer of value type str.
                """
                pass

            class PrefixObjectName(PyParameter):
                """
                Parameter PrefixObjectName of value type bool.
                """
                pass

            class UseDefaultSettings(PyParameter):
                """
                Parameter UseDefaultSettings of value type bool.
                """
                pass

            class _name_(PyTextual):
                """
                Parameter _name_ of value type str.
                """
                pass

            class Add(PyCommand):
                """
                Command Add.

                Parameters
                ----------
                Paths : List[str]

                Returns
                -------
                bool
                """
                pass

            class Remove(PyCommand):
                """
                Command Remove.

                Parameters
                ----------
                Paths : List[str]

                Returns
                -------
                bool
                """
                pass

            class Rename(PyCommand):
                """
                Command Rename.

                Parameters
                ----------
                NewName : str

                Returns
                -------
                bool
                """
                pass

        def __getitem__(self, key: str) -> _ObjectSetting:
            return super().__getitem__(key)

    class Refaceting(PyNamedObjectContainer):
        """
        .
        """
        class _Refaceting(PyMenu):
            """
            Singleton _Refaceting.
            """
            def __init__(self, service, rules, path):
                self.Applied = self.__class__.Applied(service, rules, path + [("Applied", "")])
                self.Children = self.__class__.Children(service, rules, path + [("Children", "")])
                self.Context = self.__class__.Context(service, rules, path + [("Context", "")])
                self.Deviation = self.__class__.Deviation(service, rules, path + [("Deviation", "")])
                self.MaxSize = self.__class__.MaxSize(service, rules, path + [("MaxSize", "")])
                self.Name = self.__class__.Name(service, rules, path + [("Name", "")])
                self.NormalAngle = self.__class__.NormalAngle(service, rules, path + [("NormalAngle", "")])
                self._name_ = self.__class__._name_(service, rules, path + [("_name_", "")])
                self.Add = self.__class__.Add(service, rules, "Add", path)
                self.Apply = self.__class__.Apply(service, rules, "Apply", path)
                self.Delete = self.__class__.Delete(service, rules, "Delete", path)
                self.Edit = self.__class__.Edit(service, rules, "Edit", path)
                self.Remove = self.__class__.Remove(service, rules, "Remove", path)
                self.Rename = self.__class__.Rename(service, rules, "Rename", path)
                super().__init__(service, rules, path)

            class Applied(PyParameter):
                """
                Parameter Applied of value type bool.
                """
                pass

            class Children(PyTextual):
                """
                Parameter Children of value type List[str].
                """
                pass

            class Context(PyNumerical):
                """
                Parameter Context of value type int.
                """
                pass

            class Deviation(PyNumerical):
                """
                Parameter Deviation of value type float.
                """
                pass

            class MaxSize(PyNumerical):
                """
                Parameter MaxSize of value type float.
                """
                pass

            class Name(PyTextual):
                """
                Parameter Name of value type str.
                """
                pass

            class NormalAngle(PyNumerical):
                """
                Parameter NormalAngle of value type float.
                """
                pass

            class _name_(PyTextual):
                """
                Parameter _name_ of value type str.
                """
                pass

            class Add(PyCommand):
                """
                Command Add.

                Parameters
                ----------
                Paths : List[str]

                Returns
                -------
                bool
                """
                pass

            class Apply(PyCommand):
                """
                Command Apply.


                Returns
                -------
                bool
                """
                pass

            class Delete(PyCommand):
                """
                Command Delete.


                Returns
                -------
                bool
                """
                pass

            class Edit(PyCommand):
                """
                Command Edit.


                Returns
                -------
                bool
                """
                pass

            class Remove(PyCommand):
                """
                Command Remove.

                Parameters
                ----------
                Paths : List[str]

                Returns
                -------
                bool
                """
                pass

            class Rename(PyCommand):
                """
                Command Rename.

                Parameters
                ----------
                NewName : str

                Returns
                -------
                bool
                """
                pass

        def __getitem__(self, key: str) -> _Refaceting:
            return super().__getitem__(key)

    class Rotate(PyNamedObjectContainer):
        """
        .
        """
        class _Rotate(PyMenu):
            """
            Singleton _Rotate.
            """
            def __init__(self, service, rules, path):
                self.Applied = self.__class__.Applied(service, rules, path + [("Applied", "")])
                self.Children = self.__class__.Children(service, rules, path + [("Children", "")])
                self.Context = self.__class__.Context(service, rules, path + [("Context", "")])
                self.Global = self.__class__.Global(service, rules, path + [("Global", "")])
                self.Name = self.__class__.Name(service, rules, path + [("Name", "")])
                self.RotateX = self.__class__.RotateX(service, rules, path + [("RotateX", "")])
                self.RotateY = self.__class__.RotateY(service, rules, path + [("RotateY", "")])
                self.RotateZ = self.__class__.RotateZ(service, rules, path + [("RotateZ", "")])
                self.Type = self.__class__.Type(service, rules, path + [("Type", "")])
                self._name_ = self.__class__._name_(service, rules, path + [("_name_", "")])
                self.Add = self.__class__.Add(service, rules, "Add", path)
                self.Apply = self.__class__.Apply(service, rules, "Apply", path)
                self.Remove = self.__class__.Remove(service, rules, "Remove", path)
                self.Rename = self.__class__.Rename(service, rules, "Rename", path)
                self.Undo = self.__class__.Undo(service, rules, "Undo", path)
                self.Update = self.__class__.Update(service, rules, "Update", path)
                super().__init__(service, rules, path)

            class Applied(PyParameter):
                """
                Parameter Applied of value type bool.
                """
                pass

            class Children(PyTextual):
                """
                Parameter Children of value type List[str].
                """
                pass

            class Context(PyNumerical):
                """
                Parameter Context of value type int.
                """
                pass

            class Global(PyTextual):
                """
                Parameter Global of value type str.
                """
                pass

            class Name(PyTextual):
                """
                Parameter Name of value type str.
                """
                pass

            class RotateX(PyNumerical):
                """
                Parameter RotateX of value type float.
                """
                pass

            class RotateY(PyNumerical):
                """
                Parameter RotateY of value type float.
                """
                pass

            class RotateZ(PyNumerical):
                """
                Parameter RotateZ of value type float.
                """
                pass

            class Type(PyTextual):
                """
                Parameter Type of value type str.
                """
                pass

            class _name_(PyTextual):
                """
                Parameter _name_ of value type str.
                """
                pass

            class Add(PyCommand):
                """
                Command Add.

                Parameters
                ----------
                Paths : List[str]

                Returns
                -------
                bool
                """
                pass

            class Apply(PyCommand):
                """
                Command Apply.


                Returns
                -------
                bool
                """
                pass

            class Remove(PyCommand):
                """
                Command Remove.

                Parameters
                ----------
                Paths : List[str]

                Returns
                -------
                bool
                """
                pass

            class Rename(PyCommand):
                """
                Command Rename.

                Parameters
                ----------
                NewName : str

                Returns
                -------
                bool
                """
                pass

            class Undo(PyCommand):
                """
                Command Undo.


                Returns
                -------
                bool
                """
                pass

            class Update(PyCommand):
                """
                Command Update.


                Returns
                -------
                bool
                """
                pass

        def __getitem__(self, key: str) -> _Rotate:
            return super().__getitem__(key)

    class RotateAboutAxis(PyNamedObjectContainer):
        """
        .
        """
        class _RotateAboutAxis(PyMenu):
            """
            Singleton _RotateAboutAxis.
            """
            def __init__(self, service, rules, path):
                self.Angle = self.__class__.Angle(service, rules, path + [("Angle", "")])
                self.Applied = self.__class__.Applied(service, rules, path + [("Applied", "")])
                self.AxisX = self.__class__.AxisX(service, rules, path + [("AxisX", "")])
                self.AxisY = self.__class__.AxisY(service, rules, path + [("AxisY", "")])
                self.AxisZ = self.__class__.AxisZ(service, rules, path + [("AxisZ", "")])
                self.Children = self.__class__.Children(service, rules, path + [("Children", "")])
                self.Context = self.__class__.Context(service, rules, path + [("Context", "")])
                self.Global = self.__class__.Global(service, rules, path + [("Global", "")])
                self.Name = self.__class__.Name(service, rules, path + [("Name", "")])
                self.PivotX = self.__class__.PivotX(service, rules, path + [("PivotX", "")])
                self.PivotY = self.__class__.PivotY(service, rules, path + [("PivotY", "")])
                self.PivotZ = self.__class__.PivotZ(service, rules, path + [("PivotZ", "")])
                self.Type = self.__class__.Type(service, rules, path + [("Type", "")])
                self._name_ = self.__class__._name_(service, rules, path + [("_name_", "")])
                self.Add = self.__class__.Add(service, rules, "Add", path)
                self.Apply = self.__class__.Apply(service, rules, "Apply", path)
                self.Remove = self.__class__.Remove(service, rules, "Remove", path)
                self.Rename = self.__class__.Rename(service, rules, "Rename", path)
                self.Undo = self.__class__.Undo(service, rules, "Undo", path)
                self.Update = self.__class__.Update(service, rules, "Update", path)
                super().__init__(service, rules, path)

            class Angle(PyNumerical):
                """
                Parameter Angle of value type float.
                """
                pass

            class Applied(PyParameter):
                """
                Parameter Applied of value type bool.
                """
                pass

            class AxisX(PyNumerical):
                """
                Parameter AxisX of value type float.
                """
                pass

            class AxisY(PyNumerical):
                """
                Parameter AxisY of value type float.
                """
                pass

            class AxisZ(PyNumerical):
                """
                Parameter AxisZ of value type float.
                """
                pass

            class Children(PyTextual):
                """
                Parameter Children of value type List[str].
                """
                pass

            class Context(PyNumerical):
                """
                Parameter Context of value type int.
                """
                pass

            class Global(PyTextual):
                """
                Parameter Global of value type str.
                """
                pass

            class Name(PyTextual):
                """
                Parameter Name of value type str.
                """
                pass

            class PivotX(PyNumerical):
                """
                Parameter PivotX of value type float.
                """
                pass

            class PivotY(PyNumerical):
                """
                Parameter PivotY of value type float.
                """
                pass

            class PivotZ(PyNumerical):
                """
                Parameter PivotZ of value type float.
                """
                pass

            class Type(PyTextual):
                """
                Parameter Type of value type str.
                """
                pass

            class _name_(PyTextual):
                """
                Parameter _name_ of value type str.
                """
                pass

            class Add(PyCommand):
                """
                Command Add.

                Parameters
                ----------
                Paths : List[str]

                Returns
                -------
                bool
                """
                pass

            class Apply(PyCommand):
                """
                Command Apply.


                Returns
                -------
                bool
                """
                pass

            class Remove(PyCommand):
                """
                Command Remove.

                Parameters
                ----------
                Paths : List[str]

                Returns
                -------
                bool
                """
                pass

            class Rename(PyCommand):
                """
                Command Rename.

                Parameters
                ----------
                NewName : str

                Returns
                -------
                bool
                """
                pass

            class Undo(PyCommand):
                """
                Command Undo.


                Returns
                -------
                bool
                """
                pass

            class Update(PyCommand):
                """
                Command Update.


                Returns
                -------
                bool
                """
                pass

        def __getitem__(self, key: str) -> _RotateAboutAxis:
            return super().__getitem__(key)

    class Scaling(PyNamedObjectContainer):
        """
        .
        """
        class _Scaling(PyMenu):
            """
            Singleton _Scaling.
            """
            def __init__(self, service, rules, path):
                self.Applied = self.__class__.Applied(service, rules, path + [("Applied", "")])
                self.Children = self.__class__.Children(service, rules, path + [("Children", "")])
                self.Context = self.__class__.Context(service, rules, path + [("Context", "")])
                self.Global = self.__class__.Global(service, rules, path + [("Global", "")])
                self.Name = self.__class__.Name(service, rules, path + [("Name", "")])
                self.ScaleX = self.__class__.ScaleX(service, rules, path + [("ScaleX", "")])
                self.ScaleY = self.__class__.ScaleY(service, rules, path + [("ScaleY", "")])
                self.ScaleZ = self.__class__.ScaleZ(service, rules, path + [("ScaleZ", "")])
                self.Type = self.__class__.Type(service, rules, path + [("Type", "")])
                self._name_ = self.__class__._name_(service, rules, path + [("_name_", "")])
                self.Add = self.__class__.Add(service, rules, "Add", path)
                self.Apply = self.__class__.Apply(service, rules, "Apply", path)
                self.Remove = self.__class__.Remove(service, rules, "Remove", path)
                self.Rename = self.__class__.Rename(service, rules, "Rename", path)
                self.Undo = self.__class__.Undo(service, rules, "Undo", path)
                self.Update = self.__class__.Update(service, rules, "Update", path)
                super().__init__(service, rules, path)

            class Applied(PyParameter):
                """
                Parameter Applied of value type bool.
                """
                pass

            class Children(PyTextual):
                """
                Parameter Children of value type List[str].
                """
                pass

            class Context(PyNumerical):
                """
                Parameter Context of value type int.
                """
                pass

            class Global(PyTextual):
                """
                Parameter Global of value type str.
                """
                pass

            class Name(PyTextual):
                """
                Parameter Name of value type str.
                """
                pass

            class ScaleX(PyNumerical):
                """
                Parameter ScaleX of value type float.
                """
                pass

            class ScaleY(PyNumerical):
                """
                Parameter ScaleY of value type float.
                """
                pass

            class ScaleZ(PyNumerical):
                """
                Parameter ScaleZ of value type float.
                """
                pass

            class Type(PyTextual):
                """
                Parameter Type of value type str.
                """
                pass

            class _name_(PyTextual):
                """
                Parameter _name_ of value type str.
                """
                pass

            class Add(PyCommand):
                """
                Command Add.

                Parameters
                ----------
                Paths : List[str]

                Returns
                -------
                bool
                """
                pass

            class Apply(PyCommand):
                """
                Command Apply.


                Returns
                -------
                bool
                """
                pass

            class Remove(PyCommand):
                """
                Command Remove.

                Parameters
                ----------
                Paths : List[str]

                Returns
                -------
                bool
                """
                pass

            class Rename(PyCommand):
                """
                Command Rename.

                Parameters
                ----------
                NewName : str

                Returns
                -------
                bool
                """
                pass

            class Undo(PyCommand):
                """
                Command Undo.


                Returns
                -------
                bool
                """
                pass

            class Update(PyCommand):
                """
                Command Update.


                Returns
                -------
                bool
                """
                pass

        def __getitem__(self, key: str) -> _Scaling:
            return super().__getitem__(key)

    class Transform(PyNamedObjectContainer):
        """
        .
        """
        class _Transform(PyMenu):
            """
            Singleton _Transform.
            """
            def __init__(self, service, rules, path):
                self.Applied = self.__class__.Applied(service, rules, path + [("Applied", "")])
                self.Children = self.__class__.Children(service, rules, path + [("Children", "")])
                self.Context = self.__class__.Context(service, rules, path + [("Context", "")])
                self.Global = self.__class__.Global(service, rules, path + [("Global", "")])
                self.Name = self.__class__.Name(service, rules, path + [("Name", "")])
                self.RotateX = self.__class__.RotateX(service, rules, path + [("RotateX", "")])
                self.RotateY = self.__class__.RotateY(service, rules, path + [("RotateY", "")])
                self.RotateZ = self.__class__.RotateZ(service, rules, path + [("RotateZ", "")])
                self.TranslateX = self.__class__.TranslateX(service, rules, path + [("TranslateX", "")])
                self.TranslateY = self.__class__.TranslateY(service, rules, path + [("TranslateY", "")])
                self.TranslateZ = self.__class__.TranslateZ(service, rules, path + [("TranslateZ", "")])
                self.Type = self.__class__.Type(service, rules, path + [("Type", "")])
                self._name_ = self.__class__._name_(service, rules, path + [("_name_", "")])
                self.Add = self.__class__.Add(service, rules, "Add", path)
                self.Apply = self.__class__.Apply(service, rules, "Apply", path)
                self.Delete = self.__class__.Delete(service, rules, "Delete", path)
                self.Remove = self.__class__.Remove(service, rules, "Remove", path)
                self.Rename = self.__class__.Rename(service, rules, "Rename", path)
                self.Undo = self.__class__.Undo(service, rules, "Undo", path)
                self.Update = self.__class__.Update(service, rules, "Update", path)
                super().__init__(service, rules, path)

            class Applied(PyParameter):
                """
                Parameter Applied of value type bool.
                """
                pass

            class Children(PyTextual):
                """
                Parameter Children of value type List[str].
                """
                pass

            class Context(PyNumerical):
                """
                Parameter Context of value type int.
                """
                pass

            class Global(PyTextual):
                """
                Parameter Global of value type str.
                """
                pass

            class Name(PyTextual):
                """
                Parameter Name of value type str.
                """
                pass

            class RotateX(PyNumerical):
                """
                Parameter RotateX of value type float.
                """
                pass

            class RotateY(PyNumerical):
                """
                Parameter RotateY of value type float.
                """
                pass

            class RotateZ(PyNumerical):
                """
                Parameter RotateZ of value type float.
                """
                pass

            class TranslateX(PyNumerical):
                """
                Parameter TranslateX of value type float.
                """
                pass

            class TranslateY(PyNumerical):
                """
                Parameter TranslateY of value type float.
                """
                pass

            class TranslateZ(PyNumerical):
                """
                Parameter TranslateZ of value type float.
                """
                pass

            class Type(PyTextual):
                """
                Parameter Type of value type str.
                """
                pass

            class _name_(PyTextual):
                """
                Parameter _name_ of value type str.
                """
                pass

            class Add(PyCommand):
                """
                Command Add.

                Parameters
                ----------
                Paths : List[str]

                Returns
                -------
                bool
                """
                pass

            class Apply(PyCommand):
                """
                Command Apply.


                Returns
                -------
                bool
                """
                pass

            class Delete(PyCommand):
                """
                Command Delete.

                Parameters
                ----------
                Path : str

                Returns
                -------
                bool
                """
                pass

            class Remove(PyCommand):
                """
                Command Remove.

                Parameters
                ----------
                Paths : List[str]

                Returns
                -------
                bool
                """
                pass

            class Rename(PyCommand):
                """
                Command Rename.

                Parameters
                ----------
                NewName : str

                Returns
                -------
                bool
                """
                pass

            class Undo(PyCommand):
                """
                Command Undo.


                Returns
                -------
                bool
                """
                pass

            class Update(PyCommand):
                """
                Command Update.


                Returns
                -------
                bool
                """
                pass

        def __getitem__(self, key: str) -> _Transform:
            return super().__getitem__(key)

    class TransformBase(PyNamedObjectContainer):
        """
        .
        """
        class _TransformBase(PyMenu):
            """
            Singleton _TransformBase.
            """
            def __init__(self, service, rules, path):
                self.Applied = self.__class__.Applied(service, rules, path + [("Applied", "")])
                self.Children = self.__class__.Children(service, rules, path + [("Children", "")])
                self.Context = self.__class__.Context(service, rules, path + [("Context", "")])
                self.Global = self.__class__.Global(service, rules, path + [("Global", "")])
                self.Name = self.__class__.Name(service, rules, path + [("Name", "")])
                self.Type = self.__class__.Type(service, rules, path + [("Type", "")])
                self._name_ = self.__class__._name_(service, rules, path + [("_name_", "")])
                self.Add = self.__class__.Add(service, rules, "Add", path)
                self.Apply = self.__class__.Apply(service, rules, "Apply", path)
                self.Remove = self.__class__.Remove(service, rules, "Remove", path)
                self.Rename = self.__class__.Rename(service, rules, "Rename", path)
                self.Undo = self.__class__.Undo(service, rules, "Undo", path)
                self.Update = self.__class__.Update(service, rules, "Update", path)
                super().__init__(service, rules, path)

            class Applied(PyParameter):
                """
                Parameter Applied of value type bool.
                """
                pass

            class Children(PyTextual):
                """
                Parameter Children of value type List[str].
                """
                pass

            class Context(PyNumerical):
                """
                Parameter Context of value type int.
                """
                pass

            class Global(PyTextual):
                """
                Parameter Global of value type str.
                """
                pass

            class Name(PyTextual):
                """
                Parameter Name of value type str.
                """
                pass

            class Type(PyTextual):
                """
                Parameter Type of value type str.
                """
                pass

            class _name_(PyTextual):
                """
                Parameter _name_ of value type str.
                """
                pass

            class Add(PyCommand):
                """
                Command Add.

                Parameters
                ----------
                Paths : List[str]

                Returns
                -------
                bool
                """
                pass

            class Apply(PyCommand):
                """
                Command Apply.


                Returns
                -------
                bool
                """
                pass

            class Remove(PyCommand):
                """
                Command Remove.

                Parameters
                ----------
                Paths : List[str]

                Returns
                -------
                bool
                """
                pass

            class Rename(PyCommand):
                """
                Command Rename.

                Parameters
                ----------
                NewName : str

                Returns
                -------
                bool
                """
                pass

            class Undo(PyCommand):
                """
                Command Undo.


                Returns
                -------
                bool
                """
                pass

            class Update(PyCommand):
                """
                Command Update.


                Returns
                -------
                bool
                """
                pass

        def __getitem__(self, key: str) -> _TransformBase:
            return super().__getitem__(key)

    class Translate(PyNamedObjectContainer):
        """
        .
        """
        class _Translate(PyMenu):
            """
            Singleton _Translate.
            """
            def __init__(self, service, rules, path):
                self.Applied = self.__class__.Applied(service, rules, path + [("Applied", "")])
                self.Children = self.__class__.Children(service, rules, path + [("Children", "")])
                self.Context = self.__class__.Context(service, rules, path + [("Context", "")])
                self.Global = self.__class__.Global(service, rules, path + [("Global", "")])
                self.Name = self.__class__.Name(service, rules, path + [("Name", "")])
                self.TranslateX = self.__class__.TranslateX(service, rules, path + [("TranslateX", "")])
                self.TranslateY = self.__class__.TranslateY(service, rules, path + [("TranslateY", "")])
                self.TranslateZ = self.__class__.TranslateZ(service, rules, path + [("TranslateZ", "")])
                self.Type = self.__class__.Type(service, rules, path + [("Type", "")])
                self._name_ = self.__class__._name_(service, rules, path + [("_name_", "")])
                self.Add = self.__class__.Add(service, rules, "Add", path)
                self.Apply = self.__class__.Apply(service, rules, "Apply", path)
                self.Remove = self.__class__.Remove(service, rules, "Remove", path)
                self.Rename = self.__class__.Rename(service, rules, "Rename", path)
                self.Undo = self.__class__.Undo(service, rules, "Undo", path)
                self.Update = self.__class__.Update(service, rules, "Update", path)
                super().__init__(service, rules, path)

            class Applied(PyParameter):
                """
                Parameter Applied of value type bool.
                """
                pass

            class Children(PyTextual):
                """
                Parameter Children of value type List[str].
                """
                pass

            class Context(PyNumerical):
                """
                Parameter Context of value type int.
                """
                pass

            class Global(PyTextual):
                """
                Parameter Global of value type str.
                """
                pass

            class Name(PyTextual):
                """
                Parameter Name of value type str.
                """
                pass

            class TranslateX(PyNumerical):
                """
                Parameter TranslateX of value type float.
                """
                pass

            class TranslateY(PyNumerical):
                """
                Parameter TranslateY of value type float.
                """
                pass

            class TranslateZ(PyNumerical):
                """
                Parameter TranslateZ of value type float.
                """
                pass

            class Type(PyTextual):
                """
                Parameter Type of value type str.
                """
                pass

            class _name_(PyTextual):
                """
                Parameter _name_ of value type str.
                """
                pass

            class Add(PyCommand):
                """
                Command Add.

                Parameters
                ----------
                Paths : List[str]

                Returns
                -------
                bool
                """
                pass

            class Apply(PyCommand):
                """
                Command Apply.


                Returns
                -------
                bool
                """
                pass

            class Remove(PyCommand):
                """
                Command Remove.

                Parameters
                ----------
                Paths : List[str]

                Returns
                -------
                bool
                """
                pass

            class Rename(PyCommand):
                """
                Command Rename.

                Parameters
                ----------
                NewName : str

                Returns
                -------
                bool
                """
                pass

            class Undo(PyCommand):
                """
                Command Undo.


                Returns
                -------
                bool
                """
                pass

            class Update(PyCommand):
                """
                Command Update.


                Returns
                -------
                bool
                """
                pass

        def __getitem__(self, key: str) -> _Translate:
            return super().__getitem__(key)

    class GlobalSettings(PyMenu):
        """
        Singleton GlobalSettings.
        """
        def __init__(self, service, rules, path):
            self.CurrentContext = self.__class__.CurrentContext(service, rules, path + [("CurrentContext", "")])
            self.CurrentNode = self.__class__.CurrentNode(service, rules, path + [("CurrentNode", "")])
            self.LengthUnit = self.__class__.LengthUnit(service, rules, path + [("LengthUnit", "")])
            super().__init__(service, rules, path)

        class CurrentContext(PyNumerical):
            """
            Parameter CurrentContext of value type int.
            """
            pass

        class CurrentNode(PyTextual):
            """
            Parameter CurrentNode of value type str.
            """
            pass

        class LengthUnit(PyTextual):
            """
            Parameter LengthUnit of value type str.
            """
            pass

    class MeshingOperations(PyMenu):
        """
        Singleton MeshingOperations.
        """
        def __init__(self, service, rules, path):
            self.Children = self.__class__.Children(service, rules, path + [("Children", "")])
            self.Name = self.__class__.Name(service, rules, path + [("Name", "")])
            self.DeleteAllOperations = self.__class__.DeleteAllOperations(service, rules, "DeleteAllOperations", path)
            self.UpdateAllOperations = self.__class__.UpdateAllOperations(service, rules, "UpdateAllOperations", path)
            super().__init__(service, rules, path)

        class Children(PyTextual):
            """
            Parameter Children of value type List[str].
            """
            pass

        class Name(PyTextual):
            """
            Parameter Name of value type str.
            """
            pass

        class DeleteAllOperations(PyCommand):
            """
            Command DeleteAllOperations.


            Returns
            -------
            bool
            """
            pass

        class UpdateAllOperations(PyCommand):
            """
            Command UpdateAllOperations.


            Returns
            -------
            bool
            """
            pass

    class ObjectSettingOperations(PyMenu):
        """
        Singleton ObjectSettingOperations.
        """
        def __init__(self, service, rules, path):
            self.Children = self.__class__.Children(service, rules, path + [("Children", "")])
            self.Name = self.__class__.Name(service, rules, path + [("Name", "")])
            self.CreateObjectSetting = self.__class__.CreateObjectSetting(service, rules, "CreateObjectSetting", path)
            self.DeleteAllObjectSetting = self.__class__.DeleteAllObjectSetting(service, rules, "DeleteAllObjectSetting", path)
            self.DeleteObjectSetting = self.__class__.DeleteObjectSetting(service, rules, "DeleteObjectSetting", path)
            super().__init__(service, rules, path)

        class Children(PyTextual):
            """
            Parameter Children of value type List[str].
            """
            pass

        class Name(PyTextual):
            """
            Parameter Name of value type str.
            """
            pass

        class CreateObjectSetting(PyCommand):
            """
            Command CreateObjectSetting.

            Parameters
            ----------
            Paths : List[str]

            Returns
            -------
            bool
            """
            pass

        class DeleteAllObjectSetting(PyCommand):
            """
            Command DeleteAllObjectSetting.


            Returns
            -------
            bool
            """
            pass

        class DeleteObjectSetting(PyCommand):
            """
            Command DeleteObjectSetting.

            Parameters
            ----------
            Paths : List[str]

            Returns
            -------
            bool
            """
            pass

    class RefacetingOperations(PyMenu):
        """
        Singleton RefacetingOperations.
        """
        def __init__(self, service, rules, path):
            self.Children = self.__class__.Children(service, rules, path + [("Children", "")])
            self.Name = self.__class__.Name(service, rules, path + [("Name", "")])
            self.CreateRefacet = self.__class__.CreateRefacet(service, rules, "CreateRefacet", path)
            self.DeleteAllRefacets = self.__class__.DeleteAllRefacets(service, rules, "DeleteAllRefacets", path)
            self.DeleteRefacet = self.__class__.DeleteRefacet(service, rules, "DeleteRefacet", path)
            self.UpdateAllRefacets = self.__class__.UpdateAllRefacets(service, rules, "UpdateAllRefacets", path)
            super().__init__(service, rules, path)

        class Children(PyTextual):
            """
            Parameter Children of value type List[str].
            """
            pass

        class Name(PyTextual):
            """
            Parameter Name of value type str.
            """
            pass

        class CreateRefacet(PyCommand):
            """
            Command CreateRefacet.

            Parameters
            ----------
            Paths : List[str]

            Returns
            -------
            bool
            """
            pass

        class DeleteAllRefacets(PyCommand):
            """
            Command DeleteAllRefacets.


            Returns
            -------
            bool
            """
            pass

        class DeleteRefacet(PyCommand):
            """
            Command DeleteRefacet.

            Parameters
            ----------
            Paths : List[str]

            Returns
            -------
            bool
            """
            pass

        class UpdateAllRefacets(PyCommand):
            """
            Command UpdateAllRefacets.


            Returns
            -------
            bool
            """
            pass

    class TransformOperations(PyMenu):
        """
        Singleton TransformOperations.
        """
        def __init__(self, service, rules, path):
            self.Children = self.__class__.Children(service, rules, path + [("Children", "")])
            self.Name = self.__class__.Name(service, rules, path + [("Name", "")])
            self.CreateTransform = self.__class__.CreateTransform(service, rules, "CreateTransform", path)
            self.CreateTransformType = self.__class__.CreateTransformType(service, rules, "CreateTransformType", path)
            self.DeleteAllTransforms = self.__class__.DeleteAllTransforms(service, rules, "DeleteAllTransforms", path)
            self.DeleteTransform = self.__class__.DeleteTransform(service, rules, "DeleteTransform", path)
            self.UpdateAllTransforms = self.__class__.UpdateAllTransforms(service, rules, "UpdateAllTransforms", path)
            super().__init__(service, rules, path)

        class Children(PyTextual):
            """
            Parameter Children of value type List[str].
            """
            pass

        class Name(PyTextual):
            """
            Parameter Name of value type str.
            """
            pass

        class CreateTransform(PyCommand):
            """
            Command CreateTransform.

            Parameters
            ----------
            Paths : List[str]

            Returns
            -------
            bool
            """
            pass

        class CreateTransformType(PyCommand):
            """
            Command CreateTransformType.

            Parameters
            ----------
            Type : str
            Paths : List[str]

            Returns
            -------
            bool
            """
            pass

        class DeleteAllTransforms(PyCommand):
            """
            Command DeleteAllTransforms.


            Returns
            -------
            bool
            """
            pass

        class DeleteTransform(PyCommand):
            """
            Command DeleteTransform.

            Parameters
            ----------
            Paths : List[str]

            Returns
            -------
            bool
            """
            pass

        class UpdateAllTransforms(PyCommand):
            """
            Command UpdateAllTransforms.


            Returns
            -------
            bool
            """
            pass

    class AppendFmdFiles(PyCommand):
        """
        Command AppendFmdFiles.

        Parameters
        ----------
        FilePath : List[str]
        AssemblyParentNode : int
        FileUnit : str
        Route : str
        JtLOD : str
        PartPerBody : bool
        PrefixParentName : bool
        RemoveEmptyParts : bool
        IgnoreSolidNamesAppend : bool
        Options : Dict[str, Any]

        Returns
        -------
        bool
        """
        pass

    class ChangeFileLengthUnit(PyCommand):
        """
        Command ChangeFileLengthUnit.

        Parameters
        ----------
        LengthUnit : str

        Returns
        -------
        bool
        """
        pass

    class ChangeLengthUnit(PyCommand):
        """
        Command ChangeLengthUnit.

        Parameters
        ----------
        LengthUnit : str

        Returns
        -------
        bool
        """
        pass

    class CreateObjForEachPart(PyCommand):
        """
        Command CreateObjForEachPart.

        Parameters
        ----------
        Paths : List[str]

        Returns
        -------
        bool
        """
        pass

    class CreateObjects(PyCommand):
        """
        Command CreateObjects.


        Returns
        -------
        bool
        """
        pass

    class Delete(PyCommand):
        """
        Command Delete.

        Parameters
        ----------
        Path : str

        Returns
        -------
        bool
        """
        pass

    class DeletePaths(PyCommand):
        """
        Command DeletePaths.

        Parameters
        ----------
        Paths : List[str]

        Returns
        -------
        bool
        """
        pass

    class InitializeTemplate(PyCommand):
        """
        Command InitializeTemplate.

        Parameters
        ----------
        templateType : str

        Returns
        -------
        bool
        """
        pass

    class InputFileChanged(PyCommand):
        """
        Command InputFileChanged.

        Parameters
        ----------
        FilePath : str
        PartPerBody : bool
        PrefixParentName : bool
        RemoveEmptyParts : bool
        IgnoreSolidNames : bool
        FileLengthUnit : str
        JtLOD : str
        Options : Dict[str, Any]

        Returns
        -------
        bool
        """
        pass

    class ListMeshingOperations(PyCommand):
        """
        Command ListMeshingOperations.

        Parameters
        ----------
        Path : str

        Returns
        -------
        bool
        """
        pass

    class LoadFmdFile(PyCommand):
        """
        Command LoadFmdFile.

        Parameters
        ----------
        FilePath : str
        FileUnit : str
        Route : str
        JtLOD : str
        PartPerBody : bool
        PrefixParentName : bool
        RemoveEmptyParts : bool
        IgnoreSolidNames : bool
        Options : Dict[str, Any]

        Returns
        -------
        bool
        """
        pass

    class LoadTemplate(PyCommand):
        """
        Command LoadTemplate.

        Parameters
        ----------
        FilePath : str

        Returns
        -------
        bool
        """
        pass

    class MoveCADComponentsToNewObject(PyCommand):
        """
        Command MoveCADComponentsToNewObject.

        Parameters
        ----------
        Paths : List[str]

        Returns
        -------
        bool
        """
        pass

    class MoveToNewSubobject(PyCommand):
        """
        Command MoveToNewSubobject.

        Parameters
        ----------
        Paths : List[str]

        Returns
        -------
        bool
        """
        pass

    class MoveToObject(PyCommand):
        """
        Command MoveToObject.

        Parameters
        ----------
        Paths : List[str]

        Returns
        -------
        bool
        """
        pass

    class RedoAllTransforms(PyCommand):
        """
        Command RedoAllTransforms.


        Returns
        -------
        bool
        """
        pass

    class ResetTemplate(PyCommand):
        """
        Command ResetTemplate.


        Returns
        -------
        bool
        """
        pass

    class SaveFmdFile(PyCommand):
        """
        Command SaveFmdFile.

        Parameters
        ----------
        FilePath : str

        Returns
        -------
        bool
        """
        pass

    class SaveTemplate(PyCommand):
        """
        Command SaveTemplate.

        Parameters
        ----------
        FilePath : str

        Returns
        -------
        bool
        """
        pass

    class UndoAllTransforms(PyCommand):
        """
        Command UndoAllTransforms.


        Returns
        -------
        bool
        """
        pass




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .reactions_1 import reactions as reactions_cls
from .reaction_source_term_relaxation_factor import reaction_source_term_relaxation_factor as reaction_source_term_relaxation_factor_cls
from .numerics import numerics as numerics_cls
from .numerics_dbns import numerics_dbns as numerics_dbns_cls
class expert(Group):
    """
    'expert' child.
    """

    fluent_name = "expert"

    child_names = \
        ['reactions', 'reaction_source_term_relaxation_factor', 'numerics',
         'numerics_dbns']

    reactions: reactions_cls = reactions_cls
    """
    reactions child of expert.
    """
    reaction_source_term_relaxation_factor: reaction_source_term_relaxation_factor_cls = reaction_source_term_relaxation_factor_cls
    """
    reaction_source_term_relaxation_factor child of expert.
    """
    numerics: numerics_cls = numerics_cls
    """
    numerics child of expert.
    """
    numerics_dbns: numerics_dbns_cls = numerics_dbns_cls
    """
    numerics_dbns child of expert.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enable_4 import enable as enable_cls
from .solution_method import solution_method as solution_method_cls
class do_energy_coupling(Group):
    """
    'do_energy_coupling' child.
    """

    fluent_name = "do-energy-coupling"

    child_names = \
        ['enable', 'solution_method']

    enable: enable_cls = enable_cls
    """
    enable child of do_energy_coupling.
    """
    solution_method: solution_method_cls = solution_method_cls
    """
    solution_method child of do_energy_coupling.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .width_1 import width as width_cls
from .height_1 import height as height_cls
from .margin_1 import margin as margin_cls
class pixel_size(Group):
    """
    'pixel_size' child.
    """

    fluent_name = "pixel-size"

    child_names = \
        ['width', 'height', 'margin']

    width: width_cls = width_cls
    """
    width child of pixel_size.
    """
    height: height_cls = height_cls
    """
    height child of pixel_size.
    """
    margin: margin_cls = margin_cls
    """
    margin child of pixel_size.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .node_values_1 import node_values as node_values_cls
class options(Group):
    """
    'options' child.
    """

    fluent_name = "options"

    child_names = \
        ['node_values']

    node_values: node_values_cls = node_values_cls
    """
    node_values child of options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .animation_option import animation_option as animation_option_cls
from .auto_spin import auto_spin as auto_spin_cls
from .color_map_alignment import color_map_alignment as color_map_alignment_cls
from .double_buffering import double_buffering as double_buffering_cls
from .face_displacement import face_displacement as face_displacement_cls
from .hidden_surface_method import hidden_surface_method as hidden_surface_method_cls
from .hidden_surfaces import hidden_surfaces as hidden_surfaces_cls
from .front_faces_transparent_1 import front_faces_transparent as front_faces_transparent_cls
from .show_colormap import show_colormap as show_colormap_cls
from .device_info import device_info as device_info_cls
from .driver import driver as driver_cls
from .set_rendering_options import set_rendering_options as set_rendering_options_cls
class rendering_options(Group):
    """
    'rendering_options' child.
    """

    fluent_name = "rendering-options"

    child_names = \
        ['animation_option', 'auto_spin', 'color_map_alignment',
         'double_buffering', 'face_displacement', 'hidden_surface_method',
         'hidden_surfaces', 'front_faces_transparent', 'show_colormap']

    animation_option: animation_option_cls = animation_option_cls
    """
    animation_option child of rendering_options.
    """
    auto_spin: auto_spin_cls = auto_spin_cls
    """
    auto_spin child of rendering_options.
    """
    color_map_alignment: color_map_alignment_cls = color_map_alignment_cls
    """
    color_map_alignment child of rendering_options.
    """
    double_buffering: double_buffering_cls = double_buffering_cls
    """
    double_buffering child of rendering_options.
    """
    face_displacement: face_displacement_cls = face_displacement_cls
    """
    face_displacement child of rendering_options.
    """
    hidden_surface_method: hidden_surface_method_cls = hidden_surface_method_cls
    """
    hidden_surface_method child of rendering_options.
    """
    hidden_surfaces: hidden_surfaces_cls = hidden_surfaces_cls
    """
    hidden_surfaces child of rendering_options.
    """
    front_faces_transparent: front_faces_transparent_cls = front_faces_transparent_cls
    """
    front_faces_transparent child of rendering_options.
    """
    show_colormap: show_colormap_cls = show_colormap_cls
    """
    show_colormap child of rendering_options.
    """
    command_names = \
        ['device_info', 'driver', 'set_rendering_options']

    device_info: device_info_cls = device_info_cls
    """
    device_info command of rendering_options.
    """
    driver: driver_cls = driver_cls
    """
    driver command of rendering_options.
    """
    set_rendering_options: set_rendering_options_cls = set_rendering_options_cls
    """
    set_rendering_options command of rendering_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .file import file as file_cls
from .mesh import mesh as mesh_cls
from .server import server as server_cls
from .setup import setup as setup_cls
from .solution import solution as solution_cls
from .results import results as results_cls
from .parametric_studies import parametric_studies as parametric_studies_cls
from .current_parametric_study import current_parametric_study as current_parametric_study_cls
from .parameters_2 import parameters as parameters_cls
from .parallel_1 import parallel as parallel_cls
from .exit import exit as exit_cls
class root(Group):
    """
    'root' object.
    """

    fluent_name = ""

    child_names = \
        ['file', 'mesh', 'server', 'setup', 'solution', 'results',
         'parametric_studies', 'current_parametric_study', 'parameters',
         'parallel']

    file: file_cls = file_cls
    """
    file child of root.
    """
    mesh: mesh_cls = mesh_cls
    """
    mesh child of root.
    """
    server: server_cls = server_cls
    """
    server child of root.
    """
    setup: setup_cls = setup_cls
    """
    setup child of root.
    """
    solution: solution_cls = solution_cls
    """
    solution child of root.
    """
    results: results_cls = results_cls
    """
    results child of root.
    """
    parametric_studies: parametric_studies_cls = parametric_studies_cls
    """
    parametric_studies child of root.
    """
    current_parametric_study: current_parametric_study_cls = current_parametric_study_cls
    """
    current_parametric_study child of root.
    """
    parameters: parameters_cls = parameters_cls
    """
    parameters child of root.
    """
    parallel: parallel_cls = parallel_cls
    """
    parallel child of root.
    """
    command_names = \
        ['exit']

    exit: exit_cls = exit_cls
    """
    exit command of root.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class dynamic_mechanism_reduction_target_threshold(Real):
    """
    Specify minimum mass fraction of target species.
    """

    fluent_name = "dynamic-mechanism-reduction-target-threshold"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .momentum_6 import momentum as momentum_cls
from .turbulence_1 import turbulence as turbulence_cls
from .thermal_1 import thermal as thermal_cls
from .radiation_2 import radiation as radiation_cls
from .species_6 import species as species_cls
from .dpm import dpm as dpm_cls
from .multiphase_3 import multiphase as multiphase_cls
from .potential_1 import potential as potential_cls
from .structure_1 import structure as structure_cls
from .uds_1 import uds as uds_cls
from .icing_1 import icing as icing_cls
from .geometry_2 import geometry as geometry_cls
class phase_child(Group):
    """
    'child_object_type' of phase.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['momentum', 'turbulence', 'thermal', 'radiation', 'species', 'dpm',
         'multiphase', 'potential', 'structure', 'uds', 'icing', 'geometry']

    momentum: momentum_cls = momentum_cls
    """
    momentum child of phase_child.
    """
    turbulence: turbulence_cls = turbulence_cls
    """
    turbulence child of phase_child.
    """
    thermal: thermal_cls = thermal_cls
    """
    thermal child of phase_child.
    """
    radiation: radiation_cls = radiation_cls
    """
    radiation child of phase_child.
    """
    species: species_cls = species_cls
    """
    species child of phase_child.
    """
    dpm: dpm_cls = dpm_cls
    """
    dpm child of phase_child.
    """
    multiphase: multiphase_cls = multiphase_cls
    """
    multiphase child of phase_child.
    """
    potential: potential_cls = potential_cls
    """
    potential child of phase_child.
    """
    structure: structure_cls = structure_cls
    """
    structure child of phase_child.
    """
    uds: uds_cls = uds_cls
    """
    uds child of phase_child.
    """
    icing: icing_cls = icing_cls
    """
    icing child of phase_child.
    """
    geometry: geometry_cls = geometry_cls
    """
    geometry child of phase_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .list_properties import list_properties as list_properties_cls
from .reference_frame_velocity_child import reference_frame_velocity_child

class radial_direction(ListObject[reference_frame_velocity_child]):
    """
    'radial_direction' child.
    """

    fluent_name = "radial-direction"

    command_names = \
        ['list_properties']

    list_properties: list_properties_cls = list_properties_cls
    """
    list_properties command of radial_direction.
    """
    child_object_type: reference_frame_velocity_child = reference_frame_velocity_child
    """
    child_object_type of radial_direction.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .offset import offset as offset_cls
class translate(Command):
    """
    Translate the mesh.
    
    Parameters
    ----------
        offset : typing.List[real]
            'offset' child.
    
    """

    fluent_name = "translate"

    argument_names = \
        ['offset']

    offset: offset_cls = offset_cls
    """
    offset argument of translate.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option_1 import option as option_cls
from .global_faces_per_surface_cluster import global_faces_per_surface_cluster as global_faces_per_surface_cluster_cls
from .maximum_faces_per_surface_cluster import maximum_faces_per_surface_cluster as maximum_faces_per_surface_cluster_cls
class faces_per_cluster(Group):
    """
    'faces_per_cluster' child.
    """

    fluent_name = "faces-per-cluster"

    child_names = \
        ['option', 'global_faces_per_surface_cluster',
         'maximum_faces_per_surface_cluster']

    option: option_cls = option_cls
    """
    option child of faces_per_cluster.
    """
    global_faces_per_surface_cluster: global_faces_per_surface_cluster_cls = global_faces_per_surface_cluster_cls
    """
    global_faces_per_surface_cluster child of faces_per_cluster.
    """
    maximum_faces_per_surface_cluster: maximum_faces_per_surface_cluster_cls = maximum_faces_per_surface_cluster_cls
    """
    maximum_faces_per_surface_cluster child of faces_per_cluster.
    """
